@@ -19,7 +19,8 @@
 #include "config.h"
 #include <glom/bakery/app_withdoc.h>
 #include <glom/bakery/dialog_offersave.h>
-#include <giomm/file.h>
+#include <gconfmm.h>
+#include <giomm.h>
 #include <algorithm>
 #include <glibmm/i18n-lib.h>
 
@@ -199,7 +200,6 @@ bool App_WithDoc::file_exists(const Glib::ustring& uri)
     // Try to examine the input file.
     Glib::RefPtr<Gio::File> file = Gio::File::create_for_uri(uri);
 
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
     try
     {
       return file->query_exists();
@@ -208,9 +208,6 @@ bool App_WithDoc::file_exists(const Glib::ustring& uri)
     {
       return false; //Something went wrong. It does not exist.
     }
-#else
-      return file->query_exists();
-#endif
   }
 }
 
