@@ -27,7 +27,6 @@
 #include <gtkmm/filechooserdialog.h>
 #include <gtkmm/aboutdialog.h>
 #include <giomm.h>
-#include <giomm/file.h>
 #include <algorithm>
 #include <iostream>
 
@@ -52,11 +51,6 @@ App_WithDoc_Gtk::App_WithDoc_Gtk(const Glib::ustring& appname)
   m_pAbout(0)
 {
   init_app_name(appname);
-
-#ifndef GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
-  signal_hide().connect(sigc::mem_fun(*this, &App_WithDoc_Gtk::on_hide));
-  signal_delete_event().connect(sigc::mem_fun(*this, &App_WithDoc_Gtk::on_delete_event));
-#endif
 }
 
 /// This constructor can be used with Gtk::Builder::get_derived_widget().
@@ -72,11 +66,6 @@ App_WithDoc_Gtk::App_WithDoc_Gtk(BaseObjectType* cobject, const Glib::ustring& a
   //The .glade file needs to specify HildonWindow or features such as HildonAppMenu won't work.
   g_assert(HILDON_IS_WINDOW(gobj()));
   #endif //GLOM_ENABLE_MAEMO
-
-#ifndef GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
-  signal_hide().connect(sigc::mem_fun(*this, &App_WithDoc_Gtk::on_hide));
-  signal_delete_event().connect(sigc::mem_fun(*this, &App_WithDoc_Gtk::on_delete_event));
-#endif
 }
 
   
@@ -148,7 +137,6 @@ void App_WithDoc_Gtk::init_layout()
 
 void App_WithDoc_Gtk::add_ui_from_string(const Glib::ustring& ui_description)
 {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
     m_refUIManager->add_ui_from_string(ui_description);
@@ -157,11 +145,6 @@ void App_WithDoc_Gtk::add_ui_from_string(const Glib::ustring& ui_description)
   {
     std::cerr << "building menus failed: " <<  ex.what();
   }
-#else
-  std::auto_ptr<Glib::Error> error;
-  m_refUIManager->add_ui_from_string(ui_description, error);
-  if(error.get()) std::cerr << "building menus failed: " << error->what();
-#endif
 }
 
 void App_WithDoc_Gtk::init()
@@ -238,7 +221,7 @@ void App_WithDoc_Gtk::init_menus_file_recentfiles(const Glib::ustring& path)
     Gtk::MenuItem* pMenuItem = dynamic_cast<Gtk::MenuItem*>(m_refUIManager->get_widget(path));
     if(pMenuItem)
     {
-      Gtk::RecentFilter filter;
+      Glib::RefPtr<Gtk::RecentFilter> filter = Gtk::RecentFilter::create();
 
       //Add the mime-types, so that it only shows those documents:
       for(type_list_strings::iterator iter = m_mime_types.begin(); iter != m_mime_types.end(); ++iter)
@@ -246,12 +229,11 @@ void App_WithDoc_Gtk::init_menus_file_recentfiles(const Glib::ustring& path)
         const Glib::ustring mime_type = *iter;
 
         //TODO: Find a gio equivalent for gnome_vfs_mime_type_is_known(). murrayc.
-        filter.add_mime_type(mime_type);
+        filter->add_mime_type(mime_type);
       }
 
       Gtk::RecentChooserMenu* menu = Gtk::manage(new Gtk::RecentChooserMenu);
       menu->set_filter(filter);
-      menu->set_limit(10 /* this should be a global GNOME preference, I think. */);
       menu->set_show_numbers(false);
       menu->set_sort_type(Gtk::RECENT_SORT_MRU);
       menu->signal_item_activated().connect(sigc::bind(sigc::mem_fun(*this, static_cast<void(App_WithDoc_Gtk::*)(Gtk::RecentChooser&)>(&App_WithDoc_Gtk::on_recent_files_activate)), sigc::ref(*menu)));
@@ -265,7 +247,7 @@ void App_WithDoc_Gtk::init_menus_file_recentfiles(const Glib::ustring& path)
   }
   else
   {
-    //std::cout << "debug: GlomBakery::App_WithDoc_Gtk::init_menus_file_recentfiles(): No recent files sub-menu added, because no MIME types are specified." << std::endl;
+    //std::cout << "debug: " << G_STRFUNC << ": No recent files sub-menu added, because no MIME types are specified." << std::endl;
   }
 }
 
@@ -556,7 +538,6 @@ static bool uri_is_writable(const Glib::RefPtr<const Gio::File>& uri)
 
   Glib::RefPtr<const Gio::FileInfo> file_info;
 
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
     file_info = uri->query_info(G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE);
@@ -565,12 +546,6 @@ static bool uri_is_writable(const Glib::RefPtr<const Gio::File>& uri)
   {
     return false;
   }
-#else
-  std::auto_ptr<Glib::Error> error;
-  file_info = uri->query_info(G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE, Gio::FILE_QUERY_INFO_NONE, error);
-  if(error.get())
-    return false;
-#endif
 
   if(file_info)
   {
@@ -723,13 +698,7 @@ void App_WithDoc_Gtk::document_history_add(const Glib::ustring& file_uri)
     //Glib::ustring filename_e = Gnome::Vfs::escape_path_string(file_uri);
     const Glib::ustring uri = file_uri; // "file://" + filename_e;
 
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
     Gtk::RecentManager::get_default()->add_item(uri);
-#else
-    std::auto_ptr<Glib::Error> error;
-    Gtk::RecentManager::get_default()->add_item(uri, error);
-    // Ignore error
-#endif
   }
 }
 
@@ -740,13 +709,7 @@ void App_WithDoc_Gtk::document_history_remove(const Glib::ustring& file_uri)
     //Glib::ustring filename_e = Gnome::Vfs::escape_path_string(file_uri.c_str());
     const Glib::ustring uri = file_uri; //"file://" + filename_e;
 
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
     Gtk::RecentManager::get_default()->remove_item(uri);
-#else
-    std::auto_ptr<Glib::Error> error;
-    Gtk::RecentManager::get_default()->remove_item(uri, error);
-    // Ignore error
-#endif
   }
 }
 
