@@ -18,7 +18,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "fieldtypes.h"
+#include <libglom/data_structure/fieldtypes.h>
 #include <iostream> //For debug output
 #include <libgda/gda-util.h> // For gda_g_type_to_string
 #include <libglom/connectionpool.h>
@@ -44,30 +44,21 @@ FieldTypes::FieldTypes(const Glib::RefPtr<Gnome::Gda::Connection>& gda_connectio
     //the Gda::ValueType used by Glib::RefPtr<Gnome::Gda::Column>.
     //This first call to update_meta_store() is also necessary for other calls to get_meta_store_data() elsewhere to succeed.
     Glib::RefPtr<Gnome::Gda::DataModel> data_model_tables;
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
     if(true) //Already done in ConnectionPool::connect(): gda_connection->update_meta_store())
       data_model_tables = gda_connection->get_meta_store_data(Gnome::Gda::CONNECTION_META_TYPES);
-#else
-    std::auto_ptr<Glib::Error> error;
-    if(true) //Already done in ConnectionPool::connect(): gda_connection->update_meta_store(error))
-      data_model_tables = gda_connection->get_meta_store_data(Gnome::Gda::CONNECTION_META_TYPES, error);
-
-    // Ignore error here, we do not process data_model_tables if it is NULL
-    // anyway
-#endif // GLIBMM_EXCEPTIONS_ENABLED
 
     if(!data_model_tables)
-      std::cerr << "FieldTypes::FieldTypes(): Couldn't get datamodel" << std::endl;
+      std::cerr << G_STRFUNC << ": Couldn't get datamodel" << std::endl;
 
     if(data_model_tables && (data_model_tables->get_n_columns() == 0))
     {
-      std::cerr << "FieldTypes::FieldTypes(): get_meta_store_data(Gnome::Gda::CONNECTION_META_TYPES) failed." << std::endl;
+      std::cerr << G_STRFUNC << ": get_meta_store_data(Gnome::Gda::CONNECTION_META_TYPES) failed." << std::endl;
     }
     else if(data_model_tables)
     {
       int rows = data_model_tables->get_n_rows();
       if(!rows)
-        std::cerr << "FieldTypes::FieldTypes(): no rows from CONNECTION_META_TYPES" << std::endl;
+        std::cerr << G_STRFUNC << ": no rows from CONNECTION_META_TYPES" << std::endl;
 
       for(int i = 0; i < rows; ++i)
       {
