@@ -21,8 +21,8 @@
 #ifndef GLOM_DATASTRUCTURE_LAYOUTITEM_HEADER_H
 #define GLOM_DATASTRUCTURE_LAYOUTITEM_HEADER_H
 
-#include "../layoutgroup.h"
-#include "../../field.h"
+#include <libglom/data_structure/layout/layoutgroup.h>
+#include <libglom/data_structure/field.h>
 
 namespace Glom
 {
@@ -43,9 +43,6 @@ public:
 
   virtual Glib::ustring get_part_type_name() const;
   virtual Glib::ustring get_report_part_id() const;
-
-protected:
-
 };
 
 } //namespace Glom
