@@ -27,7 +27,7 @@
 
 #include <glibmm/i18n.h>
 
-#include <giomm/file.h>
+#include <giomm.h>
 
 #include <string.h> // for strchr
 #include <sstream> //For stringstream
@@ -132,7 +132,7 @@ Glib::ustring Utils::trim_whitespace(const Glib::ustring& text)
   return result;
 }
 
-Glib::ustring Utils::string_replace(const Glib::ustring& src, const Glib::ustring search_for, const Glib::ustring& replace_with)
+Glib::ustring Utils::string_replace(const Glib::ustring& src, const Glib::ustring& search_for, const Glib::ustring& replace_with)
 {
   if(search_for.empty())
   {
@@ -441,12 +441,6 @@ Glib::RefPtr<Gnome::Gda::SqlBuilder> Utils::build_sql_select_with_key(const Glib
 
 Gnome::Gda::SqlExpr Utils::build_simple_where_expression(const Glib::ustring& table_name, const sharedptr<const Field>& key_field, const Gnome::Gda::Value& key_value)
 {
-  if(!key_field)
-  {
-    std::cerr << G_STRFUNC << ": key_field was empty" << std::endl;
-    return Gnome::Gda::SqlExpr();
-  }
-  
   Glib::RefPtr<Gnome::Gda::SqlBuilder> builder = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
   builder->select_add_target(table_name);  //This might not be necessary.
   const Gnome::Gda::SqlBuilder::Id id = builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_EQ,
@@ -486,19 +480,14 @@ Glib::RefPtr<Gnome::Gda::SqlBuilder> Utils::build_sql_select_with_key(const Glib
     sharedptr<const Relationship>(), sort_clause, limit);
 }
 
-Utils::type_list_values_with_second Utils::get_choice_values_all(const Document* document, const sharedptr<const LayoutItem_Field>& field, sharedptr<const LayoutItem_Field>& layout_choice_first, sharedptr<const LayoutItem_Field>& layout_choice_second)
+Utils::type_list_values_with_second Utils::get_choice_values_all(const Document* document, const sharedptr<const LayoutItem_Field>& field)
 {
   return get_choice_values(document, field,
-    Gnome::Gda::Value() /* means get all with no WHERE clause */,
-    layout_choice_first, layout_choice_second);
+    Gnome::Gda::Value() /* means get all with no WHERE clause */);
 }
 
-Utils::type_list_values_with_second Utils::get_choice_values(const Document* document, const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& foreign_key_value, sharedptr<const LayoutItem_Field>& layout_choice_first, sharedptr<const LayoutItem_Field>& layout_choice_second)
+Utils::type_list_values_with_second Utils::get_choice_values(const Document* document, const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& foreign_key_value)
 {
-  //Initialize output parameters:
-  layout_choice_first = sharedptr<LayoutItem_Field>();
-  layout_choice_second = sharedptr<LayoutItem_Field>();
-
   //TODO: Reduce duplication between this and get_choice_values(field).
 
   type_list_values_with_second result;
@@ -514,9 +503,10 @@ Utils::type_list_values_with_second Utils::get_choice_values(const Document* doc
 
   const FieldFormatting& format = field->get_formatting_used();
   sharedptr<const Relationship> choice_relationship;
-  Glib::ustring choice_field, choice_second;
+  sharedptr<const LayoutItem_Field> layout_choice_first;
+  sharedptr<const LayoutGroup> layout_choice_extra;
   bool choice_show_all = false;
-  format.get_choices_related(document, choice_relationship, layout_choice_first, layout_choice_second, choice_show_all);
+  format.get_choices_related(choice_relationship, layout_choice_first, layout_choice_extra, choice_show_all);
 
   if(!choice_relationship)
   {
@@ -526,11 +516,22 @@ Utils::type_list_values_with_second Utils::get_choice_values(const Document* doc
 
   Utils::type_vecConstLayoutFields fields;
   fields.push_back(layout_choice_first);
-  if(layout_choice_second)
-    fields.push_back(layout_choice_second);
+
+  if(layout_choice_extra)
+  {
+    const LayoutGroup::type_list_const_items extra_fields = layout_choice_extra->get_items_recursive();
+    for(LayoutGroup::type_list_const_items::const_iterator iter = extra_fields.begin();
+      iter != extra_fields.end(); ++iter)
+    {
+      const sharedptr<const LayoutItem> item = *iter;
+      const sharedptr<const LayoutItem_Field> item_field = sharedptr<const LayoutItem_Field>::cast_dynamic(item);
+      if(item_field)
+         fields.push_back(item_field); //TODO: Don't ignore other usable items such as static text.
+    }
+  }
 
   const Glib::ustring to_table = choice_relationship->get_to_table();
-  sharedptr<Field> to_field = document->get_field(to_table, choice_relationship->get_to_field());
+  const sharedptr<const Field> to_field = document->get_field(to_table, choice_relationship->get_to_field());
 
   if(!to_field)
   {
@@ -577,11 +578,19 @@ Utils::type_list_values_with_second Utils::get_choice_values(const Document* doc
     for(guint row = 0; row < count; ++row)
     {
 
-      std::pair<Gnome::Gda::Value, Gnome::Gda::Value> itempair;
+      std::pair<Gnome::Gda::Value, type_list_values> itempair;
       itempair.first = datamodel->get_value_at(0, row);
 
-      if(layout_choice_second && (cols_count > 1))
-        itempair.second = datamodel->get_value_at(1, row);
+      if(layout_choice_extra && (cols_count > 1))
+      {
+        type_list_values list_values;
+        for(guint i = 1; i < cols_count; ++i)
+        {
+          list_values.push_back(datamodel->get_value_at(i, row));
+        }
+
+        itempair.second = list_values;
+      }
 
       result.push_back(itempair);
     }
@@ -623,47 +632,20 @@ Glib::ustring Utils::locale_simplify(const Glib::ustring& locale_id)
 {
   Glib::ustring result = locale_id;
 
-  //At least Ubuntu Natty provides a long string such as this: LC_CTYPE=en_US.UTF-8;LC_NUMERIC=en_US.UTF-8;LC_TIME=en_US.UTF-8;LC_COLLATE=en_US.UTF-8;LC_MONETARY=en_US.UTF-8;LC_MESSAGES=en_AG.utf8;LC_PAPER=en_US.UTF-8;LC_NAME=en_US.UTF-8;LC_ADDRESS=en_US.UTF-8;LC_TELEPHONE=en_US.UTF-8;LC_MEASUREMENT=en_US.UTF-8;LC_IDENTIFICATION=en_US.UTF-8
-  //In Ubuntu Maverick, and earlier, it was apparently a simple string such as en_US.UTF-8.
-
-  //Look for LC_ALL or LC_COLLATE
-  //(We use the locale name only to identify translations
-  //Otherwise just start with the whole string.
-  Glib::ustring::size_type posCategory = result.find("LC_ALL=");
-  if(posCategory != Glib::ustring::npos)
-  {
-    result = result.substr(posCategory);
-  }
-  else
-  {
-    posCategory = result.find("LC_COLLATE=");
-    if(posCategory != Glib::ustring::npos)
-    {
-      result = result.substr(posCategory);
-    }
-  }
-
   //Get everything before the .:
-  const Glib::ustring::size_type posDot = result.find('.');
+  Glib::ustring::size_type posDot = locale_id.find('.');
   if(posDot != Glib::ustring::npos)
   {
     result = result.substr(0, posDot);
   }
 
   //Get everything before the @:
-  const Glib::ustring::size_type posAt = result.find('@');
+  const Glib::ustring::size_type posAt = locale_id.find('@');
   if(posAt != Glib::ustring::npos)
   {
     result = result.substr(0, posAt);
   }
 
-  //Get everything after the =, if any:
-  const Glib::ustring::size_type posEquals = result.find('=');
-  if(posEquals != Glib::ustring::npos)
-  {
-    result = result.substr(posEquals + 1);
-  }
-
   return result;
 }
 
@@ -1033,10 +1015,6 @@ Gnome::Gda::SqlExpr Utils::get_find_where_clause_quick(const Document* document,
     Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
   builder->select_add_target(table_name);
 
-  //We need to add some fields to select,
-  //because otherwise the SqlBuilder would not contain a valid query.
-  builder->select_add_field("*", table_name);
-
   if(!document)
   {
     std::cerr << G_STRFUNC << ": document was null." << std::endl;
@@ -1046,7 +1024,7 @@ Gnome::Gda::SqlExpr Utils::get_find_where_clause_quick(const Document* document,
   //TODO: Cache the list of all fields, as well as caching (m_Fields) the list of all visible fields:
   const Document::type_vec_fields fields = document->get_table_fields(table_name);
 
-  guint previous_id = 0;
+  guint previous_and_id = 0;
   typedef std::vector< sharedptr<LayoutItem_Field> > type_vecLayoutFields;
   type_vecLayoutFields fieldsToGet;
   for(Document::type_vec_fields::const_iterator iter = fields.begin(); iter != fields.end(); ++iter)
@@ -1063,60 +1041,32 @@ Gnome::Gda::SqlExpr Utils::get_find_where_clause_quick(const Document* document,
 
     if(use_this_field)
     {
-      //std::cout << "Using field: " << field->get_name() << std::endl;
-      const guint eq_id = builder->add_cond(field->sql_find_operator(),
+      const guint eq_id = builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_EQ, //TODO: Ue field->sql_find_operator().
         builder->add_field_id(field->get_name(), table_name),
-        builder->add_expr( field->sql_find(quick_search) )); //sql_find() modifies the value for the operator.
+        builder->add_expr(quick_search)); //Use  field->sql_find(quick_search);
 
-      if(previous_id)
+      guint and_id = 0;
+      if(previous_and_id)
       {
-        const guint or_id = builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_OR,
-          previous_id, eq_id);
-        previous_id = or_id;
+        and_id = builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_AND,
+        previous_and_id, eq_id);
       }
-      else
-        previous_id = eq_id;
+
+      previous_and_id = and_id;
     }
   }
 
-  if(previous_id)
+  if(previous_and_id)
   {
-    builder->set_where(previous_id); //This might be unnecessary.
-    //std::cout << G_STRFUNC << ": builder: " << sqlbuilder_get_full_query(builder) << std::endl; 
-    return builder->export_expression(previous_id);
+    builder->set_where(previous_and_id); //This might be unnecessary.
+    return builder->export_expression(previous_and_id);
   }
   else
   {
-    std::cerr << G_STRFUNC << ": Returning null SqlExpr" << std::endl;
     return Gnome::Gda::SqlExpr();
   }
 }
 
-
-Glib::RefPtr<Gnome::Gda::SqlBuilder> Utils::build_sql_select_count_rows(const Glib::RefPtr<const Gnome::Gda::SqlBuilder>& sql_query)
-{
-  Glib::RefPtr<Gnome::Gda::SqlBuilder> result;
-
-  if(!sql_query)
-  {
-    std::cerr << "Base_DB::count_rows_returned_by(): sql_query was null." << std::endl;
-    return result;
-  }
-
-  result = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
-
-  //Note that the alias is just because the SQL syntax requires it - we get an error if we don't use it.
-  //Be careful not to include ORDER BY clauses in this, because that would make it unnecessarily slow:
-  const guint target_id = result->add_sub_select( sql_query->get_sql_statement() );
-  result->select_add_target_id(target_id, "glomarbitraryalias");
-
-  const Gnome::Gda::SqlBuilder::Id id_function = result->add_function("COUNT", result->add_id("*"));
-  result->add_field_value_id(id_function);
-
-  return result;
-}
-
-
 bool Utils::delete_directory(const Glib::RefPtr<Gio::File>& directory)
 {
   if(!(directory->query_exists()))
@@ -1189,5 +1139,30 @@ Glib::ustring Utils::get_directory_child_with_suffix(const Glib::ustring& uri_di
   return Glib::ustring();
 }
 
+Glib::ustring Utils::get_list_of_layout_items_for_display(const LayoutGroup::type_list_items& list_layout_fields)
+{
+  Glib::ustring result;
+  for(LayoutGroup::type_list_items::const_iterator iter = list_layout_fields.begin(); iter != list_layout_fields.end(); ++iter)
+  {
+    const sharedptr<LayoutItem> item = *iter;
+    if(item)
+    {
+      if(!result.empty())
+       result += ", ";
+
+      result += item->get_layout_display_name();
+    }
+  }
+
+  return result;
+}
+
+Glib::ustring Utils::get_list_of_layout_items_for_display(const sharedptr<const LayoutGroup>& layout_group)
+{
+  if(layout_group)
+    return get_list_of_layout_items_for_display(layout_group->m_list_items);
+  else
+    return Glib::ustring();
+}
 
 } //namespace Glom
