@@ -30,10 +30,7 @@
 #include <glom/glade_utils.h>
 #include <gtkmm/main.h>
 
-#include <giomm/file.h>
-#include <glibmm/optioncontext.h>
-#include <glibmm/convert.h>
-#include <glibmm/miscutils.h>
+#include <giomm.h>
 
 // For postgres availability checks:
 #ifdef GLOM_ENABLE_POSTGRESQL
@@ -192,6 +189,7 @@ public:
   std::string m_arg_filename;
   bool m_arg_version;
   bool m_arg_restore;
+  bool m_arg_stop_auto_server_shutdown;
   bool m_arg_debug_sql;
   bool m_arg_debug_date_check;
 };
@@ -200,6 +198,7 @@ OptionGroup::OptionGroup()
 : Glib::OptionGroup("Glom", _("Glom options"), _("Command-line options for glom")),
   m_arg_version(false),
   m_arg_restore(false),
+  m_arg_stop_auto_server_shutdown(false),
   m_arg_debug_sql(false),
   m_arg_debug_date_check(false)
 {
@@ -220,6 +219,11 @@ OptionGroup::OptionGroup()
   entry_restore.set_description(_("Whether the filename is a .tar.gz backup to be restored."));
   add_entry(entry_restore, m_arg_restore);
 
+  Glib::OptionEntry entry_stop_auto_server_shutdown;
+  entry_stop_auto_server_shutdown.set_long_name("stop-auto-server-shutdown");
+  entry_stop_auto_server_shutdown.set_description(_("Do not automatically stop the database server if Glom quits. This is helpful for debugging with gdb."));
+  add_entry(entry_stop_auto_server_shutdown, m_arg_stop_auto_server_shutdown);
+
   Glib::OptionEntry entry_debug_sql;
   entry_debug_sql.set_long_name("debug_sql");
   entry_debug_sql.set_description(_("Show the generated SQL queries on stdout, for debugging."));
@@ -248,7 +252,7 @@ bool check_user_is_not_root_with_warning()
     message = ex.what();
   }
 #else
-  //std::cout << "ConnectionPool::check_user_is_not_root_with_warning(): geteuid()=" << geteuid() << ", getgid()=" << getgid() << std::endl;
+  //std::cout << "debug: " << G_STRFUNC << ": geteuid()=" << geteuid() << ", getgid()=" << getgid() << std::endl;
 
   //This is very linux-specific. We should ifdef this out for other platforms.
   if(geteuid() == 0)
@@ -292,7 +296,7 @@ bool check_user_is_not_root_with_warning()
  */
 bool check_postgres_is_available_with_warning()
 {
-  const std::string binpath = Glom::ConnectionPoolBackends::PostgresSelfHosted::get_path_to_postgres_executable("postgres", false /* not quoted */);
+  const std::string binpath = Glom::ConnectionPoolBackends::PostgresSelfHosted::get_path_to_postgres_executable("postgres");
 
   // TODO: At least on Windows we should probably also check for initdb and
   // pg_ctl. Perhaps it would also be a good idea to access these files as
@@ -471,61 +475,28 @@ main(int argc, char* argv[])
   PySys_SetArgv(argc, argv);
 
   std::auto_ptr<Gtk::Main> mainInstance;
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
-#endif
   {
     mainInstance = std::auto_ptr<Gtk::Main>( new Gtk::Main(argc, argv, context) );
   }
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   catch(const Glib::Error& ex)
   {
     std::cerr << "Glom: Error while initializing gtkmm: " << ex.what() << std::endl;
     return 0;
   }
-#else
-  if (!mainInstance.get())
-  {
-    std::cerr << "Glom: Error while initializing gtkmm" << std::endl;
-    return 0;
-  }
-#endif
 
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
-#else
-  std::auto_ptr<Glib::Error> error;
-#endif // GLIBMM_EXCEPTIONS_ENABLED
   {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
     context.parse(argc, argv);
-#else
-    context.parse(argc, argv, error);
-#endif // GLIBMM_EXCEPTIONS_ENABLED
   }
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   catch(const Glib::OptionError& ex)
-#else
-  if(error.get())
-#endif
   {
-#ifndef GLIBMM_EXCEPTIONS_ENABLED
-    const Glib::OptionError* exptr = dynamic_cast<Glib::OptionError*>(error.get());
-    if(exptr)
-    {
-      const Glib::OptionError& ex = *exptr;
-#endif // !GLIBMM_EXCEPTIONS_ENABLED
       std::cout << _("Error while parsing command-line options: ") << std::endl << ex.what() << std::endl;
       std::cout << _("Use --help to see a list of available command-line options.") << std::endl;
       return 0;
-#ifndef GLIBMM_EXCEPTIONS_ENABLED
-    }
-    const Glib::Error& ex = *error.get();
-#else
   }
   catch(const Glib::Error& ex)
   {
-#endif
     std::cout << "Error: " << ex.what() << std::endl;
     return 0;
   }
@@ -537,9 +508,7 @@ main(int argc, char* argv[])
     return 0;
   }
 
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
-#endif
   {
 #ifndef GLOM_ENABLE_CLIENT_ONLY
     gtksourceview::init();
@@ -649,6 +618,7 @@ main(int argc, char* argv[])
 
     pApplication->set_command_line_args(argc, argv);
     pApplication->set_show_sql_debug(group.m_arg_debug_sql);
+    pApplication->set_stop_auto_server_shutdown(group.m_arg_stop_auto_server_shutdown);
     Glom::ConnectionPool::get_instance()->set_show_debug_output(group.m_arg_debug_sql);
 
     const bool test = pApplication->init(input_uri, group.m_arg_restore); //Sets it up and shows it.
@@ -665,7 +635,6 @@ main(int argc, char* argv[])
     delete pApplication;
     pApplication = 0;
   }
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   catch(const Glib::Exception& ex)
   {
     //If this happens then comment out the try/catch, and let the debugger show the call stack.
@@ -676,7 +645,6 @@ main(int argc, char* argv[])
     //If this happens then comment out the try/catch, and let the debugger show the call stack.
     std::cerr << "Glom: exception: \n  " << ex.what() << std::endl;
   }
-#endif // GLIBMM_EXCEPTIONS_ENABLED
 
   Glom::libglom_deinit();
 
