@@ -28,10 +28,8 @@
 #include <glom/python_embed/glom_python.h>
 #include <glom/python_embed/python_ui_callbacks.h>
 #include <glom/application.h>
-#include <gtkmm/stock.h>
 #include <algorithm> //For std::find()
 #include <libglom/libglom_config.h>
-#include <iostream>
 #include <glibmm/i18n.h>
 
 #ifdef GLOM_ENABLE_MAEMO
@@ -95,7 +93,7 @@ Gnome::Gda::SqlExpr Box_Data::get_find_where_clause() const
   guint where_cond_id = 0;
 
   //Look at each field entry and build e.g. 'Name = "Bob"'
-  for(type_vecLayoutFields::const_iterator iter = m_FieldsShown.begin(); iter != m_FieldsShown.end(); ++iter)
+  for(type_vecConstLayoutFields::const_iterator iter = m_FieldsShown.begin(); iter != m_FieldsShown.end(); ++iter)
   {
     const Gnome::Gda::Value data = get_entered_field_data(*iter);
 
@@ -113,14 +111,14 @@ Gnome::Gda::SqlExpr Box_Data::get_find_where_clause() const
 
         if(use_this_field)
         {
-          const guint cond_id = builder->add_cond(field->sql_find_operator(),
+          const guint cond_id = builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_EQ, //TODO: Use field->sql_find_operator()
             builder->add_field_id(field->get_name(), m_table_name),
-            builder->add_expr( field->sql_find(data) ));
+            builder->add_expr(data));
 
           //And with previous condition, if any:
           if(where_cond_id)
           {
-            where_cond_id = builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_AND,
+            where_cond_id = builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_AND, //TODO: Use field->sql_find_operator()
               where_cond_id,
               cond_id);
           }
@@ -238,17 +236,17 @@ void Box_Data::on_dialog_layout_hide()
 }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-Box_Data::type_vecLayoutFields Box_Data::get_fields_to_show() const
+Box_Data::type_vecConstLayoutFields Box_Data::get_fields_to_show() const
 {
   if(m_table_name.empty())
   {
-    return type_vecLayoutFields();
+    return type_vecConstLayoutFields();
   }
   else
     return get_table_fields_to_show(m_table_name);
 }
 
-Box_Data::type_vecLayoutFields Box_Data::get_table_fields_to_show(const Glib::ustring& table_name) const
+Box_Data::type_vecConstLayoutFields Box_Data::get_table_fields_to_show(const Glib::ustring& table_name) const
 {
   const Document* pDoc = dynamic_cast<const Document*>(get_document());
   if(pDoc)
@@ -257,7 +255,7 @@ Box_Data::type_vecLayoutFields Box_Data::get_table_fields_to_show(const Glib::us
     return get_table_fields_to_show_for_sequence(table_name, mapGroupSequence);
   }
   else
-    return type_vecLayoutFields();
+    return type_vecConstLayoutFields();
 }
 
 Document::type_list_layout_groups Box_Data::get_data_layout_groups(const Glib::ustring& layout_name, const Glib::ustring& layout_platform)
@@ -271,7 +269,7 @@ Document::type_list_layout_groups Box_Data::get_data_layout_groups(const Glib::u
     {
       //Get the layout information from the document:
       layout_groups = document->get_data_layout_groups_plus_new_fields(layout_name, m_table_name, layout_platform);
-
+      document->fill_layout_field_details(m_table_name, layout_groups); //TODO: Do this automatically in Document?
       const Privileges table_privs = Privs::get_current_privs(m_table_name);
 
       //Fill in the field information for the fields mentioned in the layout:
@@ -370,19 +368,12 @@ void Box_Data::execute_button_script(const sharedptr<const LayoutItem_Button>& l
   const type_map_fields field_values = get_record_field_values_for_calculation(m_table_name, field_primary_key, primary_key_value);
 
   //We need the connection when we run the script, so that the script may use it.
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   sharedptr<SharedConnection> sharedconnection = connect_to_server(0 /* parent window */);
-#else
-  std::auto_ptr<ExceptionConnection> error;
-  sharedptr<SharedConnection> sharedconnection = connect_to_server(0 /* parent window */, error);
-  if(!error.get())
-  {
-#endif // GLIBMM_EXCEPTIONS_ENABLED
 
     //Allow this UI to respond to UI change requests from the Python code:
     AppPythonUICallbacks callbacks;
 
-    Glib::ustring error_message;
+    Glib::ustring error_message; //TODO: Check this.
     glom_execute_python_function_implementation(layout_item->get_script(),
       field_values, //TODO: Maybe use the field's type here.
       get_document(),
@@ -390,14 +381,6 @@ void Box_Data::execute_button_script(const sharedptr<const LayoutItem_Button>& l
       sharedconnection->get_gda_connection(),
       callbacks,
       error_message);
-#ifndef GLIBMM_EXCEPTIONS_ENABLED
-  }
-#endif // !GLIBMM_EXCEPTIONS_ENABLED
-
-  if(!error_message.empty())
-  {
-    std::cerr << "Python Error: " << error_message << std::endl;
-  }
 }
 
 } //namespace Glom
