@@ -64,11 +64,6 @@ Box_Data_Portal::Box_Data_Portal()
   m_layout_name = "list_portal"; //Replaced by derived classes.
 
   #ifdef GLOM_ENABLE_MAEMO
-  #ifndef GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
-  signal_realize().connect(sigc::mem_fun(*this, &Box_Data_Portal::on_realize));
-  signal_unrealize().connect(sigc::mem_fun(*this, &Box_Data_Portal::on_unrealize));
-  #endif //GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
-
   m_maemo_appmenubutton_add.signal_clicked().connect(
     sigc::mem_fun(*this, &Box_Data_Portal::on_maemo_appmenubutton_add));
   #endif //GLOM_ENABLE_MAEMO
@@ -95,18 +90,18 @@ void Box_Data_Portal::make_record_related(const Gnome::Gda::Value& related_recor
   //Create the link by setting the foreign key
   if(!m_key_field)
   {
-    std::cerr << "Box_Data_Portal::make_record_related(): m_key_field was null." << std::endl;
+    std::cerr << G_STRFUNC << ": m_key_field was null." << std::endl;
   }
 
   if(Conversions::value_is_empty(m_key_value))
   {
-    std::cerr << "Box_Data_Portal::make_record_related(): m_key_value was empty." << std::endl;
+    std::cerr << G_STRFUNC << ": m_key_value was empty." << std::endl;
   }
 
 
   if(!m_portal)
   {
-    std::cerr << "Box_Data_Portal::make_record_related(): m_portal was null." << std::endl;
+    std::cerr << G_STRFUNC << ": m_portal was null." << std::endl;
   }
 
   const Glib::ustring target_table = m_portal->get_table_used(Glib::ustring() /* not relevant */);
@@ -118,11 +113,11 @@ void Box_Data_Portal::make_record_related(const Gnome::Gda::Value& related_recor
         builder->add_field_id(field_primary_key->get_name(), target_table),
         builder->add_expr_as_value(related_record_primary_key_value)));
 
-  //std::cout << "Box_Data_Portal::make_record_related(): setting value in db=" << primary_key_value.to_string() << std::endl;
+  //std::cout << "debug: " << G_STRFUNC << ": setting value in db=" << primary_key_value.to_string() << std::endl;
   const bool test = DbUtils::query_execute(builder);
   if(!test)
   {
-    std::cerr << "Box_Data_Portal::make_record_related(): SQL query failed." << std::endl;
+    std::cerr << G_STRFUNC << ": SQL query failed." << std::endl;
   }
 }
 
@@ -254,13 +249,17 @@ bool Box_Data_Portal::init_db_details(const sharedptr<const LayoutItem_Portal>&
 
 Glib::ustring Box_Data_Portal::get_title() const
 {
-  if(m_portal)
-    return m_portal->get_title_or_name();
+  //TODO: This same code is in box_data_related_list.cc. Remove the duplication.
+  Glib::ustring relationship_title;
+  if(m_portal && m_portal->get_has_relationship_name())
+    relationship_title = m_portal->get_title_used(Glib::ustring() /* parent title - not relevant */);
   else
   {
     //Note to translators: This text is shown instead of a table title, when the table has not yet been chosen.
-    return _("Undefined Table");
+    relationship_title = _("Undefined Table");
   }
+
+  return relationship_title;
 }
 
 Glib::ustring Box_Data_Portal::get_title_singular() const
@@ -314,7 +313,7 @@ bool Box_Data_Portal::init_db_details(const Glib::ustring& parent_table, bool sh
 bool Box_Data_Portal::refresh_data_from_database_with_foreign_key(const Gnome::Gda::Value& foreign_key_value)
 {
   m_key_value = foreign_key_value;
-  //std::cout << "DEBUG: Box_Data_Portal::refresh_data_from_database_with_foreign_key(): m_key_value=" << m_key_value.to_string() << std::endl;
+  //std::cout << "debug: " << G_STRFUNC << ": m_key_value=" << m_key_value.to_string() << std::endl;
 
 
   if(m_key_field && m_portal)
@@ -324,7 +323,7 @@ bool Box_Data_Portal::refresh_data_from_database_with_foreign_key(const Gnome::G
       FoundSet found_set;
       set_found_set_where_clause_for_portal(found_set, m_portal, m_key_value);
 
-      //std::cout << "DEBUG: refresh_data_from_database_with_foreign_key(): where_clause=" << found_set.m_where_clause << std::endl;
+      //std::cout << "debug: " << G_STRFUNC << ": where_clause=" << found_set.m_where_clause << std::endl;
       return Box_Data::refresh_data_from_database_with_where_clause(found_set);
     }
     else
@@ -366,7 +365,7 @@ void Box_Data_Portal::on_record_added(const Gnome::Gda::Value& /* primary_key_va
   signal_portal_record_changed().emit(m_portal->get_relationship_name());
 }
 
-Box_Data_Portal::type_vecLayoutFields Box_Data_Portal::get_fields_to_show() const
+Box_Data_Portal::type_vecConstLayoutFields Box_Data_Portal::get_fields_to_show() const
 {
   const Document* document = get_document();
   if(document && m_portal)
@@ -377,24 +376,27 @@ Box_Data_Portal::type_vecLayoutFields Box_Data_Portal::get_fields_to_show() cons
     sharedptr<const Relationship> relationship = m_portal->get_relationship();
     if(relationship)
     {
-      type_vecLayoutFields result = get_table_fields_to_show_for_sequence(m_portal->get_table_used(Glib::ustring() /* not relevant */), mapGroups);
+      type_vecConstLayoutFields result = get_table_fields_to_show_for_sequence(m_portal->get_table_used(Glib::ustring() /* not relevant */), mapGroups);
 
       //If the relationship does not allow editing, then mark all these fields as non-editable:
+      //TODO: Prevent this in some other way:
+      /*
       if(!(m_portal->get_relationship_used_allows_edit()))
       {
-        for(type_vecLayoutFields::iterator iter = result.begin(); iter != result.end(); ++iter)
+        for(type_vecConstLayoutFields::iterator iter = result.begin(); iter != result.end(); ++iter)
         {
-          sharedptr<LayoutItem_Field> item = *iter;
+          sharedptr<const LayoutItem_Field> item = *iter;
           if(item)
             item->set_editable(false);
         }
       }
+      */
 
       return result;
     }
   }
 
-  return type_vecLayoutFields();
+  return type_vecConstLayoutFields();
 }
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -408,18 +410,70 @@ void Box_Data_Portal::on_dialog_layout_hide()
 
 bool Box_Data_Portal::get_has_suitable_record_to_view_details() const
 {
+  Glib::ustring navigation_table_name;
+  sharedptr<const UsesRelationship> navigation_relationship;
+  get_suitable_table_to_view_details(navigation_table_name, navigation_relationship);
+
+  return !(navigation_table_name.empty());
+}
+
+void Box_Data_Portal::get_suitable_table_to_view_details(Glib::ustring& table_name, sharedptr<const UsesRelationship>& relationship) const
+{
+  //Initialize output parameters:
+  table_name = Glib::ustring();
+
   if(!m_portal)
-    return false;
+    return;
+
+
+  sharedptr<const UsesRelationship> navigation_relationship = m_portal->get_navigation_relationship_specific();
+
+  //Check whether a relationship was specified:
+  if(m_portal->get_navigation_type() == LayoutItem_Portal::NAVIGATION_AUTOMATIC)
+  {
+    //std::cout << "debug: decide automatically." << std::endl;
+    //Decide automatically:
+    bool navigation_relationship_main = false; // no longer used
+    navigation_relationship = get_portal_navigation_relationship_automatic(m_portal, navigation_relationship_main);
+    //std::cout << "debug: auto main=" << navigation_relationship_main << ", navigation_relationship=" << (navigation_relationship ? navigation_relationship->get_name() : navigation_relationship->get_relationship()->get_name()) << std::endl;
+  }
+  //else
+  //  std::cout << "debug: " << G_STRFUNC << ": Using specific nav." << std::endl;
 
   const Document* document = get_document();
   if(!document)
-    return false;
-    
-  Glib::ustring navigation_table_name;
-  sharedptr<const UsesRelationship> navigation_relationship; //Ignored.
-  m_portal->get_suitable_table_to_view_details(navigation_table_name, navigation_relationship, document);
+    return;
 
-  return !(navigation_table_name.empty());
+
+  //Get the navigation table name from the chosen relationship:
+  const Glib::ustring directly_related_table_name = m_portal->get_table_used(Glib::ustring() /* not relevant */);
+
+  // The navigation_table_name (and therefore, the table_name output parameter,
+  // as well) stays empty if the navrel type was set to none.
+  Glib::ustring navigation_table_name;
+  if(m_portal->get_navigation_type() == LayoutItem_Portal::NAVIGATION_AUTOMATIC)
+  {
+    navigation_table_name = directly_related_table_name;
+  }
+  else if(m_portal->get_navigation_type() == LayoutItem_Portal::NAVIGATION_SPECIFIC)
+  {
+    navigation_table_name = navigation_relationship->get_table_used(directly_related_table_name);
+  }
+
+  if(navigation_table_name.empty())
+  {
+    //std::cerr << G_STRFUNC << ": navigation_table_name is empty." << std::endl;
+    return;
+  }
+
+  if(document->get_table_is_hidden(navigation_table_name))
+  {
+    std::cerr << G_STRFUNC << ": navigation_table_name indicates a hidden table: " << navigation_table_name << std::endl;
+    return;
+  }
+
+  table_name = navigation_table_name;
+  relationship = navigation_relationship;
 }
 
 void Box_Data_Portal::get_suitable_record_to_view_details(const Gnome::Gda::Value& primary_key_value, Glib::ustring& table_name, Gnome::Gda::Value& table_primary_key_value) const
@@ -428,16 +482,9 @@ void Box_Data_Portal::get_suitable_record_to_view_details(const Gnome::Gda::Valu
   table_name = Glib::ustring();
   table_primary_key_value = Gnome::Gda::Value();
 
-  if(!m_portal)
-    return;
-
-  const Document* document = get_document();
-  if(!document)
-    return;
-    
   Glib::ustring navigation_table_name;
   sharedptr<const UsesRelationship> navigation_relationship;
-  m_portal->get_suitable_table_to_view_details(navigation_table_name, navigation_relationship, document);
+  get_suitable_table_to_view_details(navigation_table_name, navigation_relationship);
 
   if(navigation_table_name.empty())
     return;
@@ -474,20 +521,15 @@ void Box_Data_Portal::get_suitable_record_to_view_details(const Gnome::Gda::Valu
   {
     //Set the output parameters:
     table_name = navigation_table_name;
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
     table_primary_key_value = data_model->get_value_at(0, 0);
-#else
-    std::auto_ptr<Glib::Error> error;
-    table_primary_key_value = data_model->get_value_at(0, 0, error);
-#endif
-    //std::cout << "Box_Data_Portal::get_suitable_record_to_view_details(): table_primary_key_value=" << table_primary_key_value.to_string() << std::endl;
+    //std::cout << "debug: " << G_STRFUNC << ": table_primary_key_value=" << table_primary_key_value.to_string() << std::endl;
 
     //The value is empty when there there is no record to match the key in the related table:
     //For instance, if an invoice lines record mentions a product id, but the product does not exist in the products table.
     if(Conversions::value_is_empty(table_primary_key_value))
     {
       value_found = false;
-      std::cout << "debug: Box_Data_Portal::get_suitable_record_to_view_details(): SQL query returned empty primary key." << std::endl;
+      std::cout << "debug: " << G_STRFUNC << ": SQL query returned empty primary key." << std::endl;
     }
   }
   else
