@@ -23,7 +23,6 @@
 #include "entry.h"
 #include "checkbutton.h"
 #include "label.h"
-#include <glom/mode_data/datawidget/comboentry.h>
 #include <glom/mode_data/datawidget/combo.h>
 #include <glom/mode_data/datawidget/combo_as_radio_buttons.h>
 #include <glom/mode_data/datawidget/textview.h>
@@ -36,8 +35,6 @@
 #include <glom/mode_design/layout/layout_item_dialogs/dialog_field_layout.h>
 #include <glom/utils_ui.h>
 #include <glom/glade_utils.h>
-#include <gtkmm/stock.h>
-#include <libglom/db_utils.h>
 
 #ifdef GLOM_ENABLE_MAEMO
 #include <hildonmm/button.h>
@@ -61,7 +58,7 @@ static DataWidgetChildren::ComboChoices* create_combo_widget_for_field(const sha
       result = Gtk::manage(new DataWidgetChildren::ComboGlom());
   }
   else
-    result = Gtk::manage(new DataWidgetChildren::ComboEntry());
+    result = Gtk::manage(new DataWidgetChildren::ComboGlom(true /* has_entry */));
 
   return result;
 }
@@ -122,22 +119,17 @@ DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ust
 
       if(field->get_formatting_used().get_has_custom_choices())
       {
-        //set_choices() needs this, for the numeric layout:
+        //set_choices_fixed() needs this, for the numeric layout:
         combo->set_layout_item( get_layout_item(), table_name);
 
-        combo->set_choices( field->get_formatting_used().get_choices_custom() );
+        combo->set_choices_fixed( field->get_formatting_used().get_choices_custom() );
       }
       else if(field->get_formatting_used().get_has_related_choices())
       {
         combo = create_combo_widget_for_field(field);
         combo->set_layout_item( get_layout_item(), table_name);
 
-        sharedptr<const Relationship> choice_relationship;
-        Glib::ustring choice_field, choice_second;
-        bool choice_show_all = false;
-        field->get_formatting_used().get_choices_related(choice_relationship, choice_field, choice_second, choice_show_all);
-
-        combo->set_choices_related(document, choice_relationship, choice_field, choice_second, choice_show_all);
+        combo->set_choices_related(document, field, Gnome::Gda::Value() /* TODO: Doesn't make sense */);
       }
       else
       {
@@ -188,18 +180,26 @@ DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ust
 
     bool child_added = false; //Don't use an extra container unless necessary.
 
-    //Update the field details from the document:
-    field->set_full_field_details(
-      document->get_field(field->get_table_used(table_name), field->get_name()) ); //Otherwise get_primary_key() returns false always.
+    //Check whether the field controls a relationship,
+    //meaning it identifies a record in another table.
+    const bool field_used_in_relationship_to_one = document->get_field_used_in_relationship_to_one(table_name, field);
+    //std::cout << "DEBUG: table_name=" << table_name << ", table_used=" << field->get_table_used(table_name) << ", field=" << field->get_name() << ", field_used_in_relationship_to_one=" << field_used_in_relationship_to_one << std::endl;
+
+    //Check whether the field identifies a record in another table
+    //just because it is a primary key in that table:
+    bool field_is_related_primary_key = false;
+    if(document)
+      field->set_full_field_details( document->get_field(field->get_table_used(table_name), field->get_name()) ); //Otherwise get_primary_key() returns false always.
+    sharedptr<const Field> field_info = field->get_full_field_details();
+    field_is_related_primary_key =
+      field->get_has_relationship_name() &&
+      field_info && field_info->get_primary_key();
+    //std::cout <<   "DEBUG: field->get_has_relationship_name()=" << field->get_has_relationship_name() << ", field_info->get_primary_key()=" <<  field_info->get_primary_key() << ", field_is_related_primary_key=" << field_is_related_primary_key << std::endl;
 
-    sharedptr<Relationship> field_used_in_relationship_to_one;
-    const bool add_open_button = 
-       DbUtils::layout_field_should_have_navigation(table_name, field, document, 
-         field_used_in_relationship_to_one);
 
     Gtk::HBox* hbox_parent = 0; //Only used if there are extra widgets.
 
-    const bool with_extra_widgets = field_used_in_relationship_to_one || add_open_button || (glom_type == Field::TYPE_DATE);
+    const bool with_extra_widgets = field_used_in_relationship_to_one || field_is_related_primary_key || (glom_type == Field::TYPE_DATE);
     if(with_extra_widgets)
     {
       hbox_parent = Gtk::manage( new Gtk::HBox() ); //We put the child (and any extra stuff) in this:
@@ -222,11 +222,11 @@ DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ust
       #endif
       button_date->set_tooltip_text(_("Choose a date from an on-screen calendar."));
       button_date->show();
-      hbox_parent->pack_start(*button_date, Gtk::PACK_SHRINK);
+      hbox_parent->pack_start(*button_date);
       button_date->signal_clicked().connect(sigc::mem_fun(*this, &DataWidget::on_button_choose_date));
     }
 
-    if(hbox_parent && add_open_button)
+    if((field_used_in_relationship_to_one || field_is_related_primary_key) && hbox_parent)
     {
       //Add a button for related record navigation:
       #ifndef GLOM_ENABLE_MAEMO
@@ -238,7 +238,7 @@ DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ust
       hbox_parent->pack_start(*m_button_go_to_details);
       m_button_go_to_details->signal_clicked().connect(sigc::mem_fun(*this, &DataWidget::on_button_open_details));
 
-      //Add an additional button to make it easier to choose an ID for this field.
+      //Add a button to make it easier to choose an ID for this field.
       //Don't add this for simple related primary key fields, because they
       //can generally not be edited via another table's layout.
       if(field_used_in_relationship_to_one)
@@ -290,7 +290,7 @@ void DataWidget::set_value(const Gnome::Gda::Value& value)
   if(generic_field_widget)
   {
     //if(generic_field_widget->get_layout_item())
-    //  std::cout << "DataWidget::set_value(): generic_field_widget->get_layout_item()->get_name()=" << generic_field_widget->get_layout_item()->get_name() << std::endl;
+    //  std::cout << "debug: " << G_STRFUNC << ": generic_field_widget->get_layout_item()->get_name()=" << generic_field_widget->get_layout_item()->get_name() << std::endl;
 
     generic_field_widget->set_value(value);
   }
@@ -500,6 +500,8 @@ sharedptr<LayoutItem_Field> DataWidget::offer_field_layout(const sharedptr<const
 
   Dialog_FieldLayout* dialog = 0;
   Utils::get_glade_widget_derived_with_warning(dialog);
+  if(!dialog) //Unlikely and it already warns on stderr.
+    return result;
 
   add_view(dialog); //Give it access to the document.
   dialog->set_field(start_field, m_table_name);
