@@ -53,13 +53,6 @@ FlowTableWithFields::Info::Info()
 
 FlowTableWithFields::FlowTableWithFields(const Glib::ustring& table_name)
 :
-#if !defined(GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED)
-  // This creates a custom GType for us, to override vfuncs and default
-  // signal handlers even with the reduced API (done in flowtable.cc).
-  // TODO: It is necessary to do this in all derived classes which is
-  // rather annoying, though I don't see another possibility at the moment. armin.
-  Glib::ObjectBase("Glom_FlowTable"),
-#endif // !defined(GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED)
   m_placeholder(0),
   m_table_name(table_name)
 {
@@ -197,14 +190,10 @@ void FlowTableWithFields::add_layout_group_at_position(const sharedptr<LayoutGro
 
     if(!group->get_title().empty()) //Don't indent if it has no title, to allow use of groups just for positioning.
     {
+      alignment->set_padding(Glom::Utils::DEFAULT_SPACING_SMALL, 0, 6, 0); //Use left-padding of 6 even on Maemo because indentation is important.
       #ifdef GLOM_ENABLE_MAEMO
       std::cerr << "DEBUG: Unexpected group with title causing extra spacing on Maemo." << std::endl;
       #endif
-
-      //Add some indenting just to avoid the out-denting caused by this GtkFrame bug:
-      //https://bugzilla.gnome.org/show_bug.cgi?id=644199
-      const int BASE_INDENT = 3;
-      alignment->set_padding(Glom::Utils::DEFAULT_SPACING_SMALL, 0, BASE_INDENT, 0);
     }
 
     alignment->show();
@@ -352,7 +341,7 @@ void FlowTableWithFields::add_layout_portal_at_position(const sharedptr<LayoutIt
     add_layoutwidgetbase(portal_box, add_before);
   }
   else
-    std::cerr << "FlowTableWithFields::add_layout_portal_at_position(): No portal was created." << std::endl;
+    std::cerr << G_STRFUNC << ": No portal was created." << std::endl;
 }
 
 void FlowTableWithFields::add_layout_notebook_at_position(const sharedptr<LayoutItem_Notebook>& notebook, const type_list_layoutwidgets::iterator& add_before)
@@ -378,12 +367,13 @@ void FlowTableWithFields::add_layout_notebook_at_position(const sharedptr<Layout
       Gtk::Label* tab_label = Gtk::manage(new Gtk::Label());
       tab_label->show();
 #endif
-
-      tab_label->set_label(group->get_title_or_name());
-
       sharedptr<LayoutItem_Portal> portal = sharedptr<LayoutItem_Portal>::cast_dynamic(group);
       if(portal)
       {
+        const Glib::ustring tab_title = glom_get_sharedptr_title_or_name(portal->get_relationship());
+        //tab_label->set_markup(Utils::bold_message(tab_title));
+        tab_label->set_label(tab_title);
+
         //Add a Related Records list for this portal:
         Box_Data_List_Related* portal_box = create_related(portal, false /* no label, because it's in the tab instead. */);
         //portal_box->set_border_width(Glom::Utils::DEFAULT_SPACING_SMALL); It has "padding" around the Alignment instead.
@@ -394,6 +384,10 @@ void FlowTableWithFields::add_layout_notebook_at_position(const sharedptr<Layout
       }
       else
       {
+        const Glib::ustring tab_title = group->get_title_or_name();
+        //tab_label->set_markup(Utils::bold_message(tab_title));
+        tab_label->set_label(tab_title);
+
         //Add a FlowTable for this group:
         FlowTableWithFields* flow_table = Gtk::manage( new FlowTableWithFields() );
         add_view(flow_table); //Allow these sub-flowtables to access the document too.
@@ -634,7 +628,7 @@ void FlowTableWithFields::add_textobject_at_position(const sharedptr<LayoutItem_
 
   const FieldFormatting::HorizontalAlignment alignment =
     layoutitem_text->get_formatting_used_horizontal_alignment();
-  const Gtk::AlignmentEnum x_align = (alignment == FieldFormatting::HORIZONTAL_ALIGNMENT_LEFT ? Gtk::ALIGN_START : Gtk::ALIGN_END);
+  const Gtk::Align x_align = (alignment == FieldFormatting::HORIZONTAL_ALIGNMENT_LEFT ? Gtk::ALIGN_START : Gtk::ALIGN_END);
   Gtk::Alignment* alignment_label = Gtk::manage(new Gtk::Alignment());
   alignment_label->set(x_align, Gtk::ALIGN_CENTER);
   alignment_label->show();
@@ -836,16 +830,12 @@ void FlowTableWithFields::set_other_field_value(const sharedptr<const LayoutItem
 Gnome::Gda::Value FlowTableWithFields::get_field_value(const sharedptr<const LayoutItem_Field>& field) const
 {
   type_list_const_widgets list_widgets = get_field(field, true);
-  for(type_list_const_widgets::const_iterator iter = list_widgets.begin();
-    iter != list_widgets.end(); ++iter)
+  if(!list_widgets.empty())
   {
-    const DataWidget* datawidget = dynamic_cast<const DataWidget*>(*iter);
-    if(!datawidget)
-      continue;
+    const DataWidget* datawidget = dynamic_cast<const DataWidget*>(*(list_widgets.begin()));
 
-    const Gnome::Gda::Value value = datawidget->get_value();
-    if(!Conversions::value_is_empty(value))
-      return value;
+    if(datawidget)
+      return datawidget->get_value();
   }
 
   //g_warning("FlowTableWithFields::get_field_value(): returning null");
@@ -888,7 +878,7 @@ FlowTableWithFields::type_portals FlowTableWithFields::get_portals(const sharedp
       }
       else
       {
-        std::cerr << "FlowTableWithFields::get_portals(): get_portal() returned NULL." << std::endl;
+        std::cerr << G_STRFUNC << ": get_portal() returned NULL." << std::endl;
       }
     }
   }
@@ -940,10 +930,9 @@ FlowTableWithFields::type_choice_widgets FlowTableWithFields::get_choice_widgets
 
     const FieldFormatting& format = field->get_formatting_used();
 
-    sharedptr<const Relationship> choice_relationship;
-    Glib::ustring choice_field, choice_second;
     bool choice_show_all = false;
-    format.get_choices_related(choice_relationship, choice_field, choice_second, choice_show_all);
+    const sharedptr<const Relationship> choice_relationship =
+      format.get_choices_related_relationship(choice_show_all);
     if(choice_show_all)
       continue; //"Show All" choices don't use the ID field values.
 
@@ -1190,7 +1179,7 @@ void FlowTableWithFields::on_datawidget_layout_item_added(LayoutWidgetBase::enum
   sharedptr<const LayoutItem> layout_item = pDataWidget->get_layout_item();
   if(!layout_item)
   {
-    std::cerr << "FlowTableWithFields::on_datawidget_layout_item_added(): layout_item is null." << std::endl;
+    std::cerr << G_STRFUNC << ": layout_item is null." << std::endl;
     return;
   }
 
@@ -1200,7 +1189,7 @@ void FlowTableWithFields::on_datawidget_layout_item_added(LayoutWidgetBase::enum
   sharedptr<LayoutGroup> layout_group = sharedptr<LayoutGroup>::cast_dynamic(get_layout_item());
   if(!layout_group)
   {
-    std::cerr << "FlowTableWithFields::on_datawidget_layout_item_added(): layout_group is null." << std::endl;
+    std::cerr << G_STRFUNC << ": layout_group is null." << std::endl;
     return;
   }
 
@@ -1446,7 +1435,7 @@ void FlowTableWithFields::on_dnd_add_layout_item_by_type(int item_type_num, Gtk:
       on_dnd_add_layout_portal(above);
       break;
     default:
-      std::cerr << "FlowTableWithFields::on_dnd_add_layout_item(): Unknown drop type: " << item_type << std::endl;
+      std::cerr << G_STRFUNC << ": Unknown drop type: " << item_type << std::endl;
    }
 }
 
@@ -1643,6 +1632,8 @@ void FlowTableWithFields::on_menu_properties_activate()
 {
   Dialog_FlowTable* dialog = 0;
   Utils::get_glade_widget_derived_with_warning(dialog);
+  if(!dialog) //Unlikely and it already warns on stderr.
+    return;
 
   dialog->set_flowtable(this);
   const int response = dialog->run();
@@ -1702,10 +1693,13 @@ bool FlowTableWithFields::on_button_press_event(GdkEventButton *event)
   return Gtk::Widget::on_button_press_event(event);
 }
 
+//TODO: Rename this? It's not a simpler getter. It does UI.
 sharedptr<LayoutItem_Portal> FlowTableWithFields::get_portal_relationship()
 {
   Dialog_ChooseRelationship* dialog = 0;
   Utils::get_glade_widget_derived_with_warning(dialog);
+  if(!dialog) //Unlikely and it already warns on stderr.
+    return sharedptr<LayoutItem_Portal>();
 
   Document* pDocument = static_cast<Document*>(get_document());
   dialog->set_document(pDocument, m_table_name);
