@@ -18,8 +18,8 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef GLOM_UTILITYWIDGETS_FLOWTABLEWITHFIELDS_H
-#define GLOM_UTILITYWIDGETS_FLOWTABLEWITHFIELDS_H
+#ifndef GLOM_MODE_DATA_FLOWTABLEWITHFIELDS_H
+#define GLOM_MODE_DATA_FLOWTABLEWITHFIELDS_H
 
 #include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
 
@@ -44,11 +44,6 @@
 #include <glom/mode_data/datawidget/combochoices.h>
 #include "box_data_calendar_related.h"
 #include <glom/mode_design/layout/treestore_layout.h> //Forthe enum.
-#include <gtkmm/checkbutton.h>
-#include <gtkmm/alignment.h>
-#include <gtkmm/sizegroup.h>
-#include <gtkmm/eventbox.h>
-#include <gtkmm/box.h>
 #include <map>
 #include <list>
 
@@ -304,4 +299,4 @@ private:
 
 } //namespace Glom
 
-#endif //GLOM_UTILITYWIDGETS_FLOWTABLEWITHFIELDS_H
+#endif // GLOM_MODE_DATA_FLOWTABLEWITHFIELDS_H
