@@ -20,7 +20,6 @@
 
 #include <glom/mode_data/notebook_data.h>
 #include <libglom/data_structure/glomconversions.h>
-#include <glibmm/main.h>
 #include <glibmm/i18n.h>
 
 #include <iostream>
@@ -140,13 +139,7 @@ bool Notebook_Data::init_db_details(const FoundSet& found_set, const Gnome::Gda:
   //Performance optimisation:
   //Keep the connection open during all these operations:
   {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
     sharedptr<SharedConnection> sharedconnection = connect_to_server(get_app_window());
-#else
-    std::auto_ptr<ExceptionConnection> error;
-    sharedptr<SharedConnection> sharedconnection = connect_to_server(get_app_window(), error);
-    // Ignore error, sharedconnection is not used directly within this function
-#endif
 
     result = m_Box_List.init_db_details(found_set, get_active_layout_platform(get_document())); //TODO: Select the last selected record.
 
@@ -190,7 +183,7 @@ bool Notebook_Data::init_db_details(const FoundSet& found_set, const Gnome::Gda:
       m_Box_Details.init_db_details(found_set, get_active_layout_platform(get_document()), primary_key_for_details);
     }
     else
-      std::cerr << "Notebook_Data::init_db_details(): document is NULL" << std::endl;
+      std::cerr << G_STRFUNC << ": document is NULL" << std::endl;
   }
 
 
@@ -379,7 +372,7 @@ Notebook_Data::type_signal_record_details_requested Notebook_Data::signal_record
   return m_signal_record_details_requested;
 }
 
-void Notebook_Data::on_switch_page_handler(GtkNotebookPage* pPage, guint uiPageNumber)
+void Notebook_Data::on_switch_page_handler(Gtk::Widget* pPage, guint uiPageNumber)
 {
   //Call base class:
   Notebook_Glom::on_switch_page_handler(pPage, uiPageNumber);
