@@ -22,10 +22,10 @@
  * 	Boston, MA  02110-1301, USA.
  */
 
-#ifndef GLOM_UTILITY_WIDGETS_PLACEHOLDER_GLOM_H_
-#define GLOM_UTILITY_WIDGETS_PLACEHOLDER_GLOM_H_
+#ifndef GLOM_MODE_DATA_PLACEHOLDER_GLOM_H
+#define GLOM_MODE_DATA_PLACEHOLDER_GLOM_H
 
-#include <gtkmm/widget.h>
+#include <gtkmm.h>
 #include <glom/utility_widgets/layoutwidgetbase.h>
 //#include <libglom/data_structure/layout/layoutitem_button.h>
 //#include <gtkmm/builder.h>
@@ -49,12 +49,11 @@ private:
   virtual void on_size_allocate(Gtk::Allocation& allocation);
   virtual void on_realize();
   virtual void on_unrealize();
-  virtual bool on_expose_event(GdkEventExpose* event);
+  virtual bool on_draw(const Cairo::RefPtr<Cairo::Context>& cr);
 
   Glib::RefPtr<Gdk::Window> m_refGdkWindow;
 };
 
 } // namespace Glom
 
-#endif // GLOM_UTILITY_WIDGETS_PLACEHOLDER_GLOM_H_
-
+#endif // GLOM_MODE_DATA_PLACEHOLDER_GLOM_H
