@@ -22,16 +22,10 @@
 #include "window_print_layout_edit.h"
 #include <glom/box_db_table.h>
 #include <glom/print_layout/canvas_layout_item.h>
-#include <glom/utils_ui.h>
-#include <glom/application.h>
-#include <gtkmm/radioaction.h>
-#include <gtkmm/printsettings.h>
-#include <gtkmm/stock.h>
-#include <gtkmm/table.h>
-#include <gtkmm/printoperation.h>
 #include <libglom/data_structure/layout/layoutitem_line.h>
 #include <libglom/data_structure/layout/layoutitem_portal.h>
-#include <libglom/utils.h> //For bold_message()).>
+#include <libglom/utils.h> //For bold_message()).
+#include <gtkmm/scrolledwindow.h>
 #include <glibmm/i18n.h>
 
 #include <iostream>
@@ -68,23 +62,12 @@ Window_PrintLayout_Edit::Window_PrintLayout_Edit(BaseObjectType* cobject, const
   builder->get_widget("entry_name", m_entry_name);
   builder->get_widget("entry_title", m_entry_title);
 
-  //The rulers are not in the glade file because they use an unusual widget 
-  //that Glade wouldn't usually know about:
-  m_vruler = GIMP_RULER(gimp_ruler_new(GTK_ORIENTATION_VERTICAL));
-  gtk_widget_show(GTK_WIDGET(m_vruler));
-  m_hruler = GIMP_RULER(gimp_ruler_new(GTK_ORIENTATION_HORIZONTAL));
-  gtk_widget_show(GTK_WIDGET(m_hruler));
- 
-  //Add the ruler widgets to the table at the left and top:
-  Gtk::Table* table = 0;
-  builder->get_widget("table_canvas", table);
-  gtk_table_attach(table->gobj(), GTK_WIDGET(m_vruler), 
-    0, 1, 1, 2, GTK_SHRINK, (GtkAttachOptions)(GTK_EXPAND | GTK_FILL), 0, 0);
-  gtk_table_attach(table->gobj(), GTK_WIDGET(m_hruler), 
-    1, 2, 0, 1, (GtkAttachOptions)(GTK_EXPAND | GTK_FILL), GTK_SHRINK, 0, 0);
+  builder->get_widget("vruler", m_vruler);
+  builder->get_widget("hruler", m_hruler);
 
-  gimp_ruler_set_unit(m_hruler, GIMP_UNIT_MM);
-  gimp_ruler_set_unit(m_vruler, GIMP_UNIT_MM);
+  //I'm not sure what set_metric() does, but using Gtk::CENTIMETERS leads to our max being ignored/used-weirdly. murrayc.
+  m_hruler->set_metric(Gtk::PIXELS);
+  m_vruler->set_metric(Gtk::PIXELS);
 
   builder->get_widget("handle_box", m_palette_handle_box);
 
@@ -244,7 +227,7 @@ Glib::RefPtr<Gdk::Pixbuf> Window_PrintLayout_Edit::get_icon_for_toolbar_item(Gtk
   Glib::RefPtr<Gdk::Pixbuf> result;
 
   //Set the icon to show when dragging:
-  Glib::RefPtr<Gtk::Action> action = item.get_action();
+  Glib::RefPtr<Gtk::Action> action = item.get_related_action();
   if(!action)
     return result;
 
@@ -427,7 +410,7 @@ sharedptr<LayoutItem> Window_PrintLayout_Edit::create_empty_item(PrintLayoutTool
   }
   else
   {
-    std::cerr << "Window_PrintLayout_Edit::create_empty_item(): Unhandled item type: " << item_type << std::endl;
+    std::cerr << G_STRFUNC << ": Unhandled item type: " << item_type << std::endl;
   }
 
   return layout_item;
@@ -636,10 +619,8 @@ void Window_PrintLayout_Edit::setup_context_menu()
   m_context_menu_uimanager = Gtk::UIManager::create();
   m_context_menu_uimanager->insert_action_group(m_context_menu_action_group);
 
-  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
-  #endif
     Glib::ustring ui_info = 
       "<ui>"
       "  <popup name='ContextMenu'>"
@@ -650,21 +631,12 @@ void Window_PrintLayout_Edit::setup_context_menu()
       "  </popup>"
       "</ui>";
 
-  #ifdef GLIBMM_EXCEPTIONS_ENABLED
     m_context_menu_uimanager->add_ui_from_string(ui_info);
   }
   catch(const Glib::Error& ex)
   {
     std::cerr << "building menus failed: " <<  ex.what();
   }
-  #else
-  std::auto_ptr<Glib::Error> error;
-  m_context_menu_uimanager->add_ui_from_string(ui_info, error);
-  if(error.get())
-  {
-    std::cerr << "building menus failed: " << error->what();
-  }
-  #endif
 
   //Get the menu:
   m_context_menu = dynamic_cast<Gtk::Menu*>( m_context_menu_uimanager->get_widget("/ContextMenu") ); 
@@ -862,14 +834,16 @@ void Window_PrintLayout_Edit::set_ruler_sizes()
   //Note: We should use the page size if we decide not to make the canvas bounds == page size.
   on_scroll_value_changed();
 
+  /*
   double x1 = 0;
   double y1 = 0;
   double x2 = 0;
   double y2 = 0;
   m_canvas.get_bounds(x1, y1, x2, y2);
 
-  gimp_ruler_set_range(m_hruler, x1, x2, x2);
-  gimp_ruler_set_range(m_vruler, y1, y2, x2);
+  m_hruler->set_range(x1, x2, 0, x2);
+  m_vruler->set_range(y1, y2, 0, y2);
+  */
 }
 
 void Window_PrintLayout_Edit::on_scroll_value_changed()
@@ -886,8 +860,8 @@ void Window_PrintLayout_Edit::on_scroll_value_changed()
 
   //std::cout << "DEBUG: Calling m_hruler->set_range(" << x << ", " << x + width << ", 0, " <<  x + width << std::endl;
 
-  gimp_ruler_set_range(m_hruler, x, x + width, x + width);
-  gimp_ruler_set_range(m_vruler, y, y + height, y + height);
+  m_hruler->set_range(x, x + width, 0, x + width);
+  m_vruler->set_range(y, y + height, 0, y + height);
 }
 
 bool Window_PrintLayout_Edit::on_configure_event(GdkEventConfigure* event)
