@@ -21,7 +21,8 @@
 #include "dialog_users_list.h"
 #include "dialog_user.h"
 #include "dialog_choose_user.h"
-#include <glom/glom_privs.h>
+#include <libglom/privs.h>
+#include <libglom/db_utils.h>
 #include <glom/glade_utils.h>
 #include <glom/utils_ui.h> //For bold_message()).
 //#include <libgnome/gnome-i18n.h>
@@ -183,6 +184,8 @@ void Dialog_UsersList::on_button_user_add()
 {
   Dialog_ChooseUser* dialog = 0;
   Utils::get_glade_widget_derived_with_warning(dialog);
+  if(!dialog) //Unlikely and it already warns on stderr.
+    return;
 
   dialog->set_transient_for(*this);
 
@@ -202,9 +205,9 @@ void Dialog_UsersList::on_button_user_add()
   {
     //Add it to the group:
     const Glib::ustring strQuery = "ALTER GROUP \"" + m_combo_group->get_active_text() + "\" ADD USER \"" + user + "\"";
-    const bool test = query_execute(strQuery);
+    const bool test = DbUtils::query_execute_string(strQuery);
     if(!test)
-      std::cerr << "Dialog_UsersList::on_button_user_add(): ALTER GROUP failed." << std::endl;
+      std::cerr << G_STRFUNC << ": ALTER GROUP failed." << std::endl;
 
     //Remove any user rights, so that all rights come from the user's presence in the group:
     Document::type_listTableInfo table_list = get_document()->get_tables();
@@ -212,9 +215,9 @@ void Dialog_UsersList::on_button_user_add()
     for(Document::type_listTableInfo::const_iterator iter = table_list.begin(); iter != table_list.end(); ++iter)
     {
       const Glib::ustring strQuery = "REVOKE ALL PRIVILEGES ON \"" + (*iter)->get_name() + "\" FROM \"" + user + "\"";
-      const bool test = query_execute(strQuery);
+      const bool test = DbUtils::query_execute_string(strQuery);
       if(!test)
-        std::cerr << "Dialog_UsersList::on_button_user_add(): REVOKE failed." << std::endl;
+        std::cerr << G_STRFUNC << ": REVOKE failed." << std::endl;
     }
 
     fill_list();
@@ -225,6 +228,8 @@ void Dialog_UsersList::on_button_user_new()
 {
   Dialog_User* dialog = 0;
   Utils::get_glade_widget_derived_with_warning(dialog);
+  if(!dialog) //Unlikely and it already warns on stderr.
+    return;
 
   dialog->set_transient_for(*this);
   dialog->m_combo_group->set_sensitive(false); //It is being added to the current group, so don't offer a different group.
@@ -271,6 +276,8 @@ void Dialog_UsersList::on_button_user_edit()
 
       Dialog_User* dialog = 0;
       Utils::get_glade_widget_derived_with_warning(dialog);
+      if(!dialog) //Unlikely and it already warns on stderr.
+        return;
 
       dialog->set_transient_for(*this);
 
@@ -279,7 +286,7 @@ void Dialog_UsersList::on_button_user_edit()
       dialog->m_entry_user->set_sensitive(false); //They can edit the password, but not the name. TODO: Allow editing of name?
 
       //Fill groups:
-      dialog->m_combo_group->clear_items();
+      dialog->m_combo_group->remove_all();
 
       type_vec_strings group_list = Privs::get_database_groups();
       for(type_vec_strings::const_iterator iter = group_list.begin(); iter != group_list.end(); ++iter)
@@ -319,9 +326,9 @@ void Dialog_UsersList::on_button_user_edit()
       if(!user.empty() && !password.empty())
       {
         const Glib::ustring strQuery = "ALTER USER \"" + user + "\" PASSWORD '" + password + "'" ; //TODO: Escape the password.
-        const bool test = query_execute(strQuery);
+        const bool test = DbUtils::query_execute_string(strQuery);
         if(!test)
-          std::cerr << "Dialog_UsersList::on_button_user_edit(): ALTER USER failed." << std::endl;
+          std::cerr << G_STRFUNC << ": ALTER USER failed." << std::endl;
 
         //Change the password in the current connection, if this is the current user.
         ConnectionPool* connection_pool = ConnectionPool::get_instance();
@@ -372,7 +379,7 @@ void Dialog_UsersList::fill_list()
 void Dialog_UsersList::set_group(const Glib::ustring& group_name)
 {
   //Fill the list of groups:
-  m_combo_group->clear_items();
+  m_combo_group->remove_all();
 
   type_vec_strings group_list = Privs::get_database_groups();
   for(type_vec_strings::const_iterator iter = group_list.begin(); iter != group_list.end(); ++iter)
