@@ -55,11 +55,7 @@ Canvas_PrintLayout::Canvas_PrintLayout()
 
   //Use millimeters, because that's something that is meaningful to the user,
   //and we can use it with Gtk::PageSetup too:
-  #ifdef GLIBMM_PROPERTIES_ENABLED
   property_units() = Gtk::UNIT_MM;
-  #else
-  set_property("units", Gtk::UNIT_MM);
-  #endif
 
   m_items_group = Goocanvas::Group::create();
   //m_items_group->signal_button_press_event().connect( sigc::ptr_fun(&on_group_button_press_event), false );
@@ -90,15 +86,10 @@ void Canvas_PrintLayout::set_print_layout(const Glib::ustring& table_name, const
   if(!key_file_text.empty())
   {
     Glib::KeyFile key_file;
-    
-    #ifdef GLIBMM_EXCEPTIONS_ENABLED
+
     //TODO: Catch an exception
     key_file.load_from_data(key_file_text);
-    #else
-    std::auto_ptr<Glib::Error> ex;
-    key_file.load_from_data(key_file_text, Glib::KEY_FILE_NONE, ex);
-    #endif
-    
+
     //TODO: Use this when gtkmm and GTK+ have been fixed: page_setup = Gtk::PageSetup::create(key_file);
     page_setup = Glib::wrap(gtk_page_setup_new_from_key_file(key_file.gobj(), 0, 0));
   }
@@ -116,16 +107,11 @@ sharedptr<PrintLayout> Canvas_PrintLayout::get_print_layout()
   //Page Setup:
   Glib::KeyFile key_file;
   m_page_setup->save_to_key_file(key_file);
- 
+
   Glib::ustring data;
-  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   //TODO: Catch an exception
   data = key_file.to_data();
-  #else
-  std::auto_ptr<Glib::Error> ex;
-  data = key_file.to_data(ex);
-  #endif
-  
+
   result->set_page_setup(data);
 
   return result;
@@ -176,10 +162,10 @@ void Canvas_PrintLayout::add_canvas_layout_item(const Glib::RefPtr<CanvasLayoutI
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   //Connect signals handlers:
-  //TODO: Avoid the bind of a RefPtr. It has been known to cause memory/ref-counting problems: 
+  //TODO: Avoid the bind of a RefPtr. It has been known to cause memory/ref-counting problems:
   item->signal_show_context().connect(
     sigc::bind(
-      sigc::mem_fun(*this, &Canvas_PrintLayout::on_item_show_context_menu), 
+      sigc::mem_fun(*this, &Canvas_PrintLayout::on_item_show_context_menu),
       item) );
 #endif //GLOM_ENABLE_CLIENT_ONLY
 
@@ -268,11 +254,9 @@ void Canvas_PrintLayout::setup_context_menu()
   m_context_menu_uimanager = Gtk::UIManager::create();
   m_context_menu_uimanager->insert_action_group(m_context_menu_action_group);
 
-  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
-  #endif
-    Glib::ustring ui_info = 
+    Glib::ustring ui_info =
       "<ui>"
       "  <popup name='ContextMenu'>"
       "    <menuitem action='ContextMenuEdit' />"
@@ -281,24 +265,15 @@ void Canvas_PrintLayout::setup_context_menu()
       "  </popup>"
       "</ui>";
 
-  #ifdef GLIBMM_EXCEPTIONS_ENABLED
     m_context_menu_uimanager->add_ui_from_string(ui_info);
   }
   catch(const Glib::Error& ex)
   {
     std::cerr << "building menus failed: " <<  ex.what();
   }
-  #else
-  std::auto_ptr<Glib::Error> error;
-  m_context_menu_uimanager->add_ui_from_string(ui_info, error);
-  if(error.get())
-  {
-    std::cerr << "building menus failed: " << error->what();
-  }
-  #endif
 
   //Get the menu:
-  m_context_menu = dynamic_cast<Gtk::Menu*>( m_context_menu_uimanager->get_widget("/ContextMenu") ); 
+  m_context_menu = dynamic_cast<Gtk::Menu*>( m_context_menu_uimanager->get_widget("/ContextMenu") );
 }
 
 
@@ -318,6 +293,8 @@ sharedptr<LayoutItem_Portal> Canvas_PrintLayout::offer_related_records(const sha
 
   Dialog_Layout_List_Related* dialog = 0;
   Utils::get_glade_widget_derived_with_warning(dialog);
+  if(!dialog) //Unlikely and it already warns on stderr.
+    return result;
 
   add_view(dialog); //Give it access to the document.
 
@@ -387,7 +364,7 @@ void Canvas_PrintLayout::on_context_menu_formatting()
 {
   if(!m_context_item)
     return;
-  
+
   sharedptr<LayoutItem> layout_item = m_context_item->get_layout_item();
   update_layout_position_from_canvas(layout_item, m_context_item);
 
@@ -410,13 +387,18 @@ void Canvas_PrintLayout::on_context_menu_formatting()
 
   //We need an if here, because they have no common base class.
   //TODO: Maybe they should.
-  FieldFormatting formatting;
   if(layout_item_field)
-    formatting = layout_item_field->m_formatting;
+  {
+    const FieldFormatting& formatting = layout_item_field->m_formatting;
+    m_dialog_format->m_box_formatting->set_formatting_for_field(formatting, m_table_name, layout_item_field->get_full_field_details());
+  }
   else
-    formatting = layout_item_text->m_formatting;
+  {
+    const FieldFormatting& formatting = layout_item_text->m_formatting;
+    m_dialog_format->m_box_formatting->set_formatting_for_non_field(formatting);
+  }
 
-  m_dialog_format->m_box_formatting->set_formatting(formatting);
+  m_dialog_format->m_box_formatting->set_is_for_non_editable();
 
   m_dialog_format->show();
 }
@@ -461,25 +443,20 @@ void Canvas_PrintLayout::update_layout_position_from_canvas(const sharedptr<Layo
   double x = 0;
   double y = 0;
   canvas_item->get_xy(x, y);
-  //std::cout << "Canvas_PrintLayout::update_layout_position_from_canvas(): x=" << x << std::endl;
+  //std::cout << "debug: " << G_STRFUNC << ": x=" << x << std::endl;
 
   double width = 0;
   double height = 0;
   canvas_item->get_width_height(width, height);
-  layout_item->set_print_layout_position(x, y, width, height); 
+  layout_item->set_print_layout_position(x, y, width, height);
 }
 
 Glib::RefPtr<Goocanvas::Polyline> Canvas_PrintLayout::create_margin_line(double x1, double y1, double x2, double y2)
 {
-  Glib::RefPtr<Goocanvas::Polyline> line = 
+  Glib::RefPtr<Goocanvas::Polyline> line =
     Goocanvas::Polyline::create(x1, y1, x2, y2);
-  #ifdef GLIBMM_PROPERTIES_ENABLED
   line->property_line_width() = 0.5;
   line->property_stroke_color() = "light gray";
-  #else
-  line->set_property("line-width", 0.5);
-  line->set_property("stroke-color", Glib::ustring("light gray"));
-  #endif
 
   m_bounds_group->add_child(line);
   return line;
@@ -497,14 +474,9 @@ void Canvas_PrintLayout::set_page_setup(const Glib::RefPtr<Gtk::PageSetup>& page
   bounds.set_x1(0);
   bounds.set_y1(0);
 
-  #ifdef GLIBMM_PROPERTIES_ENABLED
   const Gtk::Unit units = property_units();
-  #else
-  Gtk::Unit units = Gtk::UNIT_MM;
-  get_property("units", units);
-  #endif
 
-  //std::cout << "Canvas_PrintLayout::set_page_setup(): width=" << paper_size.get_width(units) << ", height=" paper_size.get_height(units) << std::endl;
+  //std::cout << "debug: " << G_STRFUNC << ": width=" << paper_size.get_width(units) << ", height=" paper_size.get_height(units) << std::endl;
 
   if(m_page_setup->get_orientation() == Gtk::PAGE_ORIENTATION_PORTRAIT) //TODO: Handle the reverse orientations too?
   {
@@ -517,16 +489,12 @@ void Canvas_PrintLayout::set_page_setup(const Glib::RefPtr<Gtk::PageSetup>& page
     bounds.set_x2( paper_size.get_height(units) );
   }
 
-  //std::cout << "Canvas_PrintLayout::set_page_setup(): portrait page width=" << paper_size.get_width(units) << std::endl;
+  //std::cout << "debug: " << G_STRFUNC << ": portrait page width=" << paper_size.get_width(units) << std::endl;
 
   set_bounds(bounds);
 
   //Show the bounds with a rectangle, because the scrolled window might contain extra empty space.
-  #ifdef GLIBMM_PROPERTIES_ENABLED
   property_background_color() = "light gray";
-  #else
-  set_property("background-color", Glib::ustring("light gray"));
-  #endif
   if(m_bounds_group)
   {
     m_bounds_group->remove();
@@ -536,23 +504,18 @@ void Canvas_PrintLayout::set_page_setup(const Glib::RefPtr<Gtk::PageSetup>& page
   Glib::RefPtr<Goocanvas::Item> root = get_root_item();
   m_bounds_group = Goocanvas::Group::create();
   root->add_child(m_bounds_group);
-  
- 
+
+
   m_bounds_rect = Goocanvas::Rect::create(bounds.get_x1(), bounds.get_y1(), bounds.get_x2(), bounds.get_y2());
-  #ifdef GLIBMM_PROPERTIES_ENABLED
   m_bounds_rect->property_fill_color() = "white";
   m_bounds_rect->property_line_width() = 0;
-  #else
-  m_bounds_rect->set_property("fill-color", Glib::ustring("white"));
-  m_bounds_rect->set_property("line-width", 0);
-  #endif
   m_bounds_group->add_child(m_bounds_rect);
 
-  //Make sure that the bounds rect is at the bottom, 
+  //Make sure that the bounds rect is at the bottom,
   //and that the grid and margins are just above it:
   if(m_grid)
     m_grid->lower();
-  
+
   m_margin_left = create_margin_line(page_setup->get_left_margin(units), bounds.get_y1(), page_setup->get_left_margin(units), bounds.get_y2());
   m_margin_right = create_margin_line(bounds.get_x2() - page_setup->get_right_margin(units), bounds.get_y1(), bounds.get_x2() - page_setup->get_right_margin(units), bounds.get_y2());
   m_margin_top = create_margin_line(bounds.get_x1(), page_setup->get_top_margin(units), bounds.get_x2(), page_setup->get_top_margin(units));
@@ -579,7 +542,7 @@ void Canvas_PrintLayout::fill_with_data(const Glib::RefPtr<Goocanvas::Group>& ca
 
   typedef std::list< sharedptr<LayoutItem_Portal> > type_list_portals;
   type_list_portals list_portals;
-  
+
   //Get list of fields to get from the database.
   Utils::type_vecLayoutFields fieldsToGet;
   const int count = canvas_group->get_n_children();
@@ -590,17 +553,17 @@ void Canvas_PrintLayout::fill_with_data(const Glib::RefPtr<Goocanvas::Group>& ca
     Glib::RefPtr<CanvasLayoutItem> canvas_item = Glib::RefPtr<CanvasLayoutItem>::cast_dynamic(base_canvas_item);
     if(!canvas_item)
       continue;
-      
+
     sharedptr<LayoutItem> layout_item = canvas_item->get_layout_item();
     if(!layout_item)
       continue;
-      
+
     sharedptr<LayoutItem_Field> layoutitem_field = sharedptr<LayoutItem_Field>::cast_dynamic(layout_item);
     if(layoutitem_field && !(layoutitem_field->get_name().empty()))
     {
       fieldsToGet.push_back(layoutitem_field);
-      
-      //Remember the index so we can use it later, 
+
+      //Remember the index so we can use it later,
       //to get the data for this column from the query results:
       map_fields_index[ layoutitem_field->get_layout_display_name() ] = field_i;
       ++field_i;
@@ -629,15 +592,12 @@ void Canvas_PrintLayout::fill_with_data(const Glib::RefPtr<Goocanvas::Group>& ca
     fieldsToGet,
     found_set.m_where_clause, sharedptr<const Relationship>() /* extra_join */, found_set.m_sort_clause,
     1);
-  
+
   bool records_found = false;
   Glib::RefPtr<Gnome::Gda::DataModel> datamodel;
-  #ifdef GLIBMM_EXCEPTIONS_ENABLED //TODO: Catch the error somehow?
   try
   {
-  #endif
     datamodel = DbUtils::query_execute_select(sql_query);
-  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   }
   catch(const Glib::Exception& ex)
   {
@@ -647,7 +607,6 @@ void Canvas_PrintLayout::fill_with_data(const Glib::RefPtr<Goocanvas::Group>& ca
   {
     std::cout << "Canvas_PrintLayout::fill_with_data: exception: " << ex.what() << std::endl;
   }
-  #endif
 
   if(datamodel)
   {
@@ -655,7 +614,7 @@ void Canvas_PrintLayout::fill_with_data(const Glib::RefPtr<Goocanvas::Group>& ca
     if(rows_count > 0)
       records_found = true;
   }
-  
+
   if(!records_found)
     return;
 
@@ -667,27 +626,22 @@ void Canvas_PrintLayout::fill_with_data(const Glib::RefPtr<Goocanvas::Group>& ca
     Glib::RefPtr<CanvasLayoutItem> canvas_item = Glib::RefPtr<CanvasLayoutItem>::cast_dynamic(base_canvas_item);
     if(!canvas_item)
       continue;
-      
+
     sharedptr<LayoutItem> layout_item = canvas_item->get_layout_item();
     if(!layout_item)
       continue;
-      
+
     sharedptr<LayoutItem_Field> layoutitem_field = sharedptr<LayoutItem_Field>::cast_dynamic(layout_item);
     if(layoutitem_field)
-    { 
+    {
       type_map_layout_fields_index::const_iterator iterFind = map_fields_index.find( layoutitem_field->get_layout_display_name() );
       if(iterFind != map_fields_index.end())
       {
         //Set the data from the database:
         const guint col_index = iterFind->second;
 
-        #ifdef GLIBMM_EXCEPTIONS_ENABLED
         //TODO: Actually catch exception:
         const Gnome::Gda::Value value = datamodel->get_value_at(col_index, 0);
-        #else
-        std::auto_ptr<Glib::Error> ex;
-        const Gnome::Gda::Value value = datamodel->get_value_at(col_index, 0, ex);
-        #endif
         canvas_item->set_db_data(value);
       }
     }
@@ -723,9 +677,9 @@ void Canvas_PrintLayout::fill_with_data_portal(const Glib::RefPtr<CanvasLayoutIt
   //TODO: Move the child stuff into group in goocanvas.
 
   LayoutGroup::type_list_items child_layout_items = portal->get_items();
-  
+
   //Build and run the SQL query for this portal:
-  type_vecLayoutFields fields_shown = get_portal_fields_to_show(portal);
+  type_vecConstLayoutFields fields_shown = get_portal_fields_to_show(portal);
 
   FoundSet found_set;
   found_set.m_table_name = portal->get_table_used(Glib::ustring() /* parent table_name, not used. */);
@@ -736,11 +690,11 @@ void Canvas_PrintLayout::fill_with_data_portal(const Glib::RefPtr<CanvasLayoutIt
   Glib::RefPtr<Gnome::Gda::DataModel> datamodel = DbUtils::query_execute_select(sql_query);
   if(!(datamodel))
     return;
-    
+
   const int db_rows_count = datamodel->get_n_rows();
   if(!(db_rows_count > 0))
     return;
-    
+
   const int db_columns_count = datamodel->get_n_columns();
   if(!db_columns_count)
     return;
@@ -756,14 +710,14 @@ void Canvas_PrintLayout::fill_with_data_portal(const Glib::RefPtr<CanvasLayoutIt
     LayoutGroup::type_list_items::iterator iter_child_layout_items = child_layout_items.begin();
     for(int col = 0; col < cols_count; ++col)
     {
-      //Glib::RefPtr<Goocanvas::Item> canvas_child = base_item->get_cell_child(row, col); //TODO: Add this to GooCanvas::Table.
-      Glib::RefPtr<Goocanvas::Item> canvas_child = get_canvas_table_cell_child(canvas_table, row, col); //TODO: Add this to GooCanvas::Table.
+      //Glib::RefPtr<Goocanvas::Item> canvas_child = base_item->get_cell_child(row, col); //TODO: Add this to Goocanvas::Table.
+      Glib::RefPtr<Goocanvas::Item> canvas_child = get_canvas_table_cell_child(canvas_table, row, col); //TODO: Add this to Goocanvas::Table.
       if(!canvas_child)
-        std::cerr << "Canvas_PrintLayout::fill_with_data_portal(): canvas_child is NULL." << std::endl;
+        std::cerr << G_STRFUNC << ": canvas_child is NULL." << std::endl;
 
       if(iter_child_layout_items == child_layout_items.end())
         continue;
-      
+
       sharedptr<LayoutItem> child_layout_item = *iter_child_layout_items;
       sharedptr<LayoutItem_Field> field = sharedptr<LayoutItem_Field>::cast_dynamic(child_layout_item);
       if(field)
@@ -771,15 +725,10 @@ void Canvas_PrintLayout::fill_with_data_portal(const Glib::RefPtr<CanvasLayoutIt
         Gnome::Gda::Value db_value;
         if( row < datamodel->get_n_rows() )
         {
-          #ifdef GLIBMM_EXCEPTIONS_ENABLED
           //TODO: Actually catch exception.
           db_value = datamodel->get_value_at(db_col, row);
-          #else
-          std::auto_ptr<Glib::Error> ex;
-          db_value = datamodel->get_value_at(db_col, row, ex);
-          #endif
         }
-          
+
         set_canvas_item_field_value(canvas_child, field, db_value);
         ++db_col;
       }
@@ -802,24 +751,20 @@ void Canvas_PrintLayout::set_canvas_item_field_value(const Glib::RefPtr<Goocanva
       return;
 
     Glib::RefPtr<Gdk::Pixbuf> pixbuf = Utils::get_pixbuf_for_gda_value(value);
-    #ifdef GLIBMM_PROPERTIES_ENABLED
     canvas_image->property_pixbuf() = pixbuf;
-    #else
-    canvas_image->set_property("pixbuf", pixbuf);
-    #endif
   }
   else //text, numbers, date, time, boolean:
   {
     Glib::RefPtr<CanvasTextMovable> canvas_text = Glib::RefPtr<CanvasTextMovable>::cast_dynamic(canvas_item);
     if(!canvas_text)
     {
-      std::cerr << "Canvas_PrintLayout::set_canvas_item_field_value(): The canvas item is not of the expected type. Instead it is of type." << std::endl;
+      std::cerr << G_STRFUNC << ": The canvas item is not of the expected type. Instead it is of type." << std::endl;
       return;
     }
 
     //FieldFormatting& formatting = field->m_formatting;
     //apply_formatting(canvas_item, formatting);
-    const Glib::ustring text = 
+    const Glib::ustring text =
       Conversions::get_text_for_gda_value(field->get_glom_type(), value, field->m_formatting.m_numeric_format);
     canvas_text->set_text(text);
   }
@@ -844,18 +789,14 @@ guint Canvas_PrintLayout::get_zoom_percent() const
 
 void Canvas_PrintLayout::hide_page_bounds()
 {
-  #ifdef GLIBMM_PROPERTIES_ENABLED
   m_bounds_group->property_visibility() = Goocanvas::ITEM_HIDDEN;
-  #else
-  m_bounds_group->set_property("visibility", Goocanvas::ITEM_HIDDEN);
-  #endif
 }
 
 void Canvas_PrintLayout::set_grid_gap(double gap)
 {
   CanvasEditable::set_grid_gap(gap);
 
-  //Make sure that the bounds rect is at the bottom, 
+  //Make sure that the bounds rect is at the bottom,
   //and that the grid and margins are just above it:
   if(m_grid)
     m_grid->lower();
@@ -882,7 +823,7 @@ Glib::RefPtr<Goocanvas::Item> Canvas_PrintLayout::get_canvas_table_cell_child(co
     table->get_child_property(child, "column", column_value);
     int row_value = 0;
     table->get_child_property(child, "row", row_value);
-       
+
     //This assumes that all items occupy only one cell:
     if( (column_value == col) &&
         (row_value == row) )
@@ -896,11 +837,11 @@ Glib::RefPtr<Goocanvas::Item> Canvas_PrintLayout::get_canvas_table_cell_child(co
 
 
 
-Base_DB::type_vecLayoutFields Canvas_PrintLayout::get_portal_fields_to_show(const sharedptr<LayoutItem_Portal>& portal)
+Base_DB::type_vecConstLayoutFields Canvas_PrintLayout::get_portal_fields_to_show(const sharedptr<LayoutItem_Portal>& portal)
 {
   const Document* document = get_document();
   if(!document)
-    std::cerr << "Canvas_PrintLayout::get_portal_fields_to_show(): document is NULL." << std::endl;
+    std::cerr << G_STRFUNC << ": document is NULL." << std::endl;
 
   if(document && portal)
   {
@@ -910,27 +851,27 @@ Base_DB::type_vecLayoutFields Canvas_PrintLayout::get_portal_fields_to_show(cons
     sharedptr<const Relationship> relationship = portal->get_relationship();
     if(relationship)
     {
-      type_vecLayoutFields result = get_table_fields_to_show_for_sequence(portal->get_table_used(Glib::ustring() /* not relevant */), mapGroups);
+      type_vecConstLayoutFields result = get_table_fields_to_show_for_sequence(portal->get_table_used(Glib::ustring() /* not relevant */), mapGroups);
 
       //If the relationship does not allow editing, then mark all these fields as non-editable:
+      /* TODO: Find a better way to do this.
       if(!(portal->get_relationship_used_allows_edit()))
       {
-        for(type_vecLayoutFields::iterator iter = result.begin(); iter != result.end(); ++iter)
+        for(type_vecConstLayoutFields::iterator iter = result.begin(); iter != result.end(); ++iter)
         {
-          sharedptr<LayoutItem_Field> item = *iter;
+          sharedptr<const LayoutItem_Field> item = *iter;
           if(item)
             item->set_editable(false);
         }
       }
+      */
 
       return result;
     }
   }
 
-  return type_vecLayoutFields();
+  return type_vecConstLayoutFields();
 }
 
 
 } //namespace Glom
-
-
