@@ -28,9 +28,6 @@
 #include <libglom/data_structure/layout/report_parts/layoutitem_footer.h>
 #include <libglom/db_utils.h>
 #include <glom/xsl_utils.h>
-#include <iostream>
-#include <glibmm/miscutils.h>
-#include <glibmm/i18n.h>
 
 namespace Glom
 {
@@ -176,7 +173,7 @@ void ReportBuilder::report_build_groupby(const FoundSet& found_set_parent, xmlpp
   if(group_by->get_has_field_group_by())
   {
     sharedptr<LayoutItem_Field> field_group_by = group_by->get_field_group_by();
-    fill_full_field_details(found_set_parent.m_table_name, field_group_by);
+    DbUtils::layout_item_fill_field_details(get_document(), found_set_parent.m_table_name, field_group_by);
 
     //Get the possible group values, ignoring repeats by using GROUP BY.
     const Glib::ustring group_field_table_name = field_group_by->get_table_used(found_set_parent.m_table_name);
@@ -199,12 +196,7 @@ void ReportBuilder::report_build_groupby(const FoundSet& found_set_parent, xmlpp
       guint rows_count = datamodel->get_n_rows();
       for(guint row = 0; row < rows_count; ++row)
       {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
         const Gnome::Gda::Value group_value = datamodel->get_value_at(0 /* col*/, row);
-#else
-        std::auto_ptr<Glib::Error> error;
-        const Gnome::Gda::Value group_value = datamodel->get_value_at(0 /* col*/, row, error);
-#endif
 
 
         //Add XML node:
@@ -409,23 +401,13 @@ void ReportBuilder::report_build_records_field(const FoundSet& found_set, xmlpp:
     if(!datamodel)
       return;
 
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
     value = datamodel->get_value_at(colField, row);
-#else
-    std::auto_ptr<Glib::Error> error;
-    value = datamodel->get_value_at(colField, row, error);
-#endif
     colField = 0;
     row = 0;
   }
   else
   {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
     value = datamodel->get_value_at(colField, row);
-#else
-    std::auto_ptr<Glib::Error> error;
-    value = datamodel->get_value_at(colField, row, error);
-#endif
   }
 
   nodeField->set_attribute("title", field->get_title_or_name()); //Not always used, but useful.
@@ -578,7 +560,6 @@ void ReportBuilder::report_build(const FoundSet& found_set, const sharedptr<cons
     // not to be in glom, otherwise the code wouldn't compile with
     // -fno-exceptions. If it's in a library, it does not seem to take an
     // additional error paramater for that. armin.
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
     try
     {
       report_build_records(found_set, *nodeGroupBy, itemsToGet_TopLevel);
@@ -595,9 +576,6 @@ void ReportBuilder::report_build(const FoundSet& found_set, const sharedptr<cons
       handle_error(ex);
       return;
     }
-#else
-    report_build_records(found_set, *nodeGroupBy, itemsToGet_TopLevel);
-#endif
   }
 
   GlomXslUtils::transform_and_open(*pDocument, "print_report_to_html.xsl", parent_window);
