@@ -21,153 +21,27 @@
 #include "flowtable.h"
 #include "layoutwidgetbase.h"
 #include <iostream>
-#include <gtkmm/eventbox.h>
 #include <gdkmm/window.h>
 #include <glom/utils_ui.h>
 
-
-namespace Glom
-{
-
-#ifndef GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
-
-GtkContainerClass* parent_class = 0;
-
-// TODO: It is probably OK doing static_cast here.
-void FlowTable::glom_size_request_impl(GtkWidget* widget, GtkRequisition* requisition)
-{
-  Glib::ObjectBase *const obj_base = static_cast<Glib::ObjectBase*>(
-    Glib::ObjectBase::_get_current_wrapper((GObject*)widget));
-
-  if(obj_base)
-  {
-    Glom::FlowTable* table = dynamic_cast<Glom::FlowTable*>(obj_base);
-    g_assert(table);
-    table->on_size_request(requisition);
-  }
-  else if(GTK_WIDGET_CLASS(parent_class)->size_request)
-    GTK_WIDGET_CLASS(parent_class)->size_request(widget, requisition);
-}
-
-void FlowTable::glom_size_allocate_impl(GtkWidget* widget, GtkAllocation* allocation)
-{
-  Glib::ObjectBase *const obj_base = static_cast<Glib::ObjectBase*>(
-    Glib::ObjectBase::_get_current_wrapper((GObject*)widget));
-
-  if(obj_base)
-  {
-    Glom::FlowTable* table = dynamic_cast<Glom::FlowTable*>(obj_base);
-    g_assert(table);
-
-    Gtk::Allocation cpp_allocation = Glib::wrap(allocation);
-    table->on_size_allocate(cpp_allocation);
-    *allocation = *cpp_allocation.gobj();
-  }
-  else if(GTK_WIDGET_CLASS(parent_class)->size_allocate)
-    GTK_WIDGET_CLASS(parent_class)->size_allocate(widget, allocation);
-}
-
-void FlowTable::glom_add_impl(GtkContainer* container, GtkWidget* widget)
-{
-  Glib::ObjectBase *const obj_base = static_cast<Glib::ObjectBase*>(
-    Glib::ObjectBase::_get_current_wrapper((GObject*)container));
-
-  if(obj_base)
-  {
-    Glom::FlowTable* table = dynamic_cast<Glom::FlowTable*>(obj_base);
-    g_assert(table);
-    table->on_add(Glib::wrap(widget));
-  }
-  else if(parent_class->add)
-    parent_class->add(container, widget);
-}
-
-void FlowTable::glom_remove_impl(GtkContainer* container, GtkWidget* widget)
-{
-  Glib::ObjectBase *const obj_base = static_cast<Glib::ObjectBase*>(
-    Glib::ObjectBase::_get_current_wrapper((GObject*)container));
-
-  if(obj_base)
-  {
-    Glom::FlowTable* table = dynamic_cast<Glom::FlowTable*>(obj_base);
-    g_assert(table);
-    table->on_remove(Glib::wrap(widget));
-  }
-  else if(parent_class->remove)
-    parent_class->remove(container, widget);
-}
-
-void FlowTable::glom_realize_impl(GtkWidget* widget)
-{
-  Glib::ObjectBase *const obj_base = static_cast<Glib::ObjectBase*>(
-    Glib::ObjectBase::_get_current_wrapper((GObject*)widget));
-
-  if(obj_base)
-  {
-    Glom::FlowTable* table = dynamic_cast<Glom::FlowTable*>(obj_base);
-    g_assert(table);
-    table->on_realize();
-  }
-  else if(GTK_WIDGET_CLASS(parent_class)->realize)
-    GTK_WIDGET_CLASS(parent_class)->realize(widget);
-}
-
-void FlowTable::glom_unrealize_impl(GtkWidget* widget)
-{
-  Glib::ObjectBase *const obj_base = static_cast<Glib::ObjectBase*>(
-    Glib::ObjectBase::_get_current_wrapper((GObject*)widget));
-
-  if(obj_base)
-  {
-    Glom::FlowTable* table = dynamic_cast<Glom::FlowTable*>(obj_base);
-    g_assert(table);
-    table->on_unrealize();
-  }
-  else if(GTK_WIDGET_CLASS(parent_class)->unrealize)
-    GTK_WIDGET_CLASS(parent_class)->unrealize(widget);
-}
-
-gboolean FlowTable::glom_expose_event_impl(GtkWidget* widget, GdkEventExpose* event)
-{
-  Glib::ObjectBase *const obj_base = static_cast<Glib::ObjectBase*>(
-    Glib::ObjectBase::_get_current_wrapper((GObject*)widget));
-
-  if(obj_base)
-  {
-    Glom::FlowTable* table = dynamic_cast<Glom::FlowTable*>(obj_base);
-    g_assert(table);
-    return table->on_expose_event(event);
-  }
-  else if(GTK_WIDGET_CLASS(parent_class)->expose_event)
-    return GTK_WIDGET_CLASS(parent_class)->expose_event(widget, event);
-  else
-    return false;
-}
-#endif // !GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
-} //namespace Glom
-
 namespace Glom
 {
 
 static void container_forall_callback(GtkWidget* widget_gobj, void* data)
 {
-  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
-  #endif //GLIBMM_EXCEPTIONS_ENABLED
     FlowTable::ForallSlot& slot = *static_cast<FlowTable::ForallSlot*>(data);
     Gtk::Widget *const widget = Glib::wrap(widget_gobj);
 
     g_return_if_fail(widget != 0);
 
     slot(*widget);
-  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   }
   catch(...)
   {
     Glib::exception_handlers_invoke();
   }
-  #endif //GLIBMM_EXCEPTIONS_ENABLED
 }
 
 
@@ -196,44 +70,12 @@ FlowTable::FlowTableItem::FlowTableItem(Gtk::Widget* first, Gtk::Widget* second,
 
 FlowTable::FlowTable()
 :
-#if !defined(GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED)
-  // This creates a custom GType for us, to override vfuncs and default
-  // signal handlers even with the reduced API.
-  // TODO: It is necessary to do this in all derived classes which is
-  // rather annoying, though I don't see another possibility at the moment. armin.
-  Glib::ObjectBase("Glom_FlowTable"),
-#endif // ! !defined(GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED)
   m_columns_allocated_changed(false),
   m_columns_count(1),
   m_column_padding(Utils::DEFAULT_SPACING_SMALL), //A sane default.
   m_row_padding(Utils::DEFAULT_SPACING_SMALL), //A sane default.
   m_design_mode(false)
 {
-#if !defined(GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED)
-  // TODO: Thread safety?
-  // TODO: We could also set up a Glib::Class derived object with a custom
-  // class init function so we do not need to lookup the class object by
-  // the underlaying gobj() as we do currently.
-  if(!parent_class)
-  {
-    GtkContainerClass* container_class = G_TYPE_INSTANCE_GET_CLASS(gobj(), G_TYPE_FROM_INSTANCE(gobj()), GtkContainerClass);
-    GtkWidgetClass* widget_class = GTK_WIDGET_CLASS(container_class);
-
-#ifndef GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
-    container_class->add = &Glom::FlowTable::glom_add_impl;
-    container_class->remove = &Glom::FlowTable::glom_remove_impl;
-
-    widget_class->size_request = &Glom::FlowTable::glom_size_request_impl;
-    widget_class->size_allocate = &Glom::FlowTable::glom_size_allocate_impl;
-    widget_class->realize = &Glom::FlowTable::glom_realize_impl;
-    widget_class->unrealize = &Glom::FlowTable::glom_unrealize_impl;
-    widget_class->expose_event = &Glom::FlowTable::glom_expose_event_impl;
-#endif // !GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
-
-    parent_class = GTK_CONTAINER_CLASS(g_type_class_peek_parent(container_class));
-  }
-#endif // !defined(GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED)
-
   set_has_window(false);
   set_redraw_on_allocate(false);
 }
@@ -387,17 +229,19 @@ void FlowTable::get_item_requested_width(const FlowTableItem& item, int& first,
     if(child_is_visible(first_widget))
     {
       //Discover how much space this child needs:
-      Gtk::Requisition child_requisition_request;
-      child_requisition_request = first_widget->size_request();
-      first = child_requisition_request.width;
+      //TODO: Which one should we use?
+      Gtk::Requisition child_requisition_request_min, child_requisition_request_natural;
+      first_widget->get_preferred_size(child_requisition_request_min, child_requisition_request_natural);
+      first = child_requisition_request_natural.width;
     }
 
     if(child_is_visible(second_widget))
     {
       //Discover how much space this child needs:
-      Gtk::Requisition child_requisition_request;
-      child_requisition_request = second_widget->size_request();
-      second = child_requisition_request.width;
+      //TODO: Which one should we use?
+      Gtk::Requisition child_requisition_request_min, child_requisition_request_natural;
+      second_widget->get_preferred_size(child_requisition_request_min, child_requisition_request_natural);
+      second = child_requisition_request_min.width;
     }
   }
 }
@@ -415,19 +259,21 @@ int FlowTable::get_item_requested_height(const FlowTableItem& item) const
     if(child_is_visible(first))
     {
       // Ask the child how much space it needs:
-      Gtk::Requisition child_requisition;
-      child_requisition = first->size_request();
+      //TODO: Which one should we use?
+      Gtk::Requisition child_requisition_request_min, child_requisition_request_natural;
+      first->get_preferred_size(child_requisition_request_min, child_requisition_request_natural);
 
-      max_child_height = child_requisition.height;
+      max_child_height = child_requisition_request_min.height;
     }
 
     if(child_is_visible(second))
     {
       // Ask the child how much space it needs:
-      Gtk::Requisition child_requisition;
-      child_requisition = second->size_request();
+      //TODO: Which one should we use?
+      Gtk::Requisition child_requisition_request_min, child_requisition_request_natural;
+      second->get_preferred_size(child_requisition_request_min, child_requisition_request_natural);
 
-      max_child_height = MAX(max_child_height, child_requisition.height);
+      max_child_height = MAX(max_child_height, child_requisition_request_min.height);
     }
 
     //Use the largest height (they are next to each other, horizontally):
@@ -602,12 +448,13 @@ Gtk::Allocation FlowTable::assign_child(Gtk::Widget* widget, int x, int y, int w
 //Give it whatever height/width it wants, at this location:
 Gtk::Allocation FlowTable::assign_child(Gtk::Widget* widget, int x, int y)
 {
-  //Discover how much space this child needs:
-  Gtk::Requisition child_requisition_request;
-  child_requisition_request = widget->size_request();
+  //Discover how much space this child needs:;
+  //TODO: Which one should we use?
+  Gtk::Requisition child_requisition_request_min, child_requisition_request_natural;
+  widget->get_preferred_size(child_requisition_request_min, child_requisition_request_natural);
 
   //Give it as much space as it wants:
-  return assign_child(widget, x, y, child_requisition_request.width, child_requisition_request.height);
+  return assign_child(widget, x, y, child_requisition_request_min.width, child_requisition_request_min.height);
 }
 
 void FlowTable::get_item_max_width_requested(guint start, guint height, guint& first_max_width, guint& second_max_width, guint& singles_max_width, bool& is_last_column) const
@@ -641,33 +488,35 @@ void FlowTable::get_item_max_width_requested(guint start, guint height, guint& f
     guint singles_width = 0;
     if(child_is_visible(first))
     {
-      Gtk::Requisition child_requisition;
-      child_requisition = first->size_request();
+      //TODO: Which one should we use?
+      Gtk::Requisition child_requisition_request_min, child_requisition_request_natural;
+      first->get_preferred_size(child_requisition_request_min, child_requisition_request_natural);
 
       if(child_is_visible(second))
       {
         //There are 2 widgets so put one in each sub-column, lined up with the widgets in the other rows:
-        item_first_width = child_requisition.width;
+        item_first_width = child_requisition_request_min.width;
       }
       else
       {
         //There is only one widget, so let it take up the whole space and not affect the widths of the sub-columns:
-        singles_width = child_requisition.width;
+        singles_width = child_requisition_request_min.width;
       }
 
-      height_item = MAX(height_item, (guint)child_requisition.height);
+      height_item = MAX(height_item, (guint)child_requisition_request_min.height);
       first_item_added = true;
     }
 
     guint item_second_width = 0;
     if(child_is_visible(second))
     {
-      Gtk::Requisition child_requisition;
-      child_requisition = second->size_request();
+      //TODO: Which one should we use?
+      Gtk::Requisition child_requisition_request_min, child_requisition_request_natural;
+      second->get_preferred_size(child_requisition_request_min, child_requisition_request_natural);
 
-      item_second_width = child_requisition.width;
+      item_second_width = child_requisition_request_min.width;
       //g_warning("item_second_width=%d", item_second_width);
-      height_item = MAX(height_item, (guint)child_requisition.height);
+      height_item = MAX(height_item, (guint)child_requisition_request_min.height);
       first_item_added = true;
     }
 
@@ -702,7 +551,7 @@ void FlowTable::on_size_allocate(Gtk::Allocation& allocation)
 
   set_allocation(allocation);
 
-  //This will be used in on_expose_event():
+  //This will be used in on_draw():
   m_lines_horizontal.clear();
   m_lines_vertical.clear();
 
@@ -1014,12 +863,7 @@ void FlowTable::remove_all()
 
 void FlowTable::on_realize()
 {
-#ifdef GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
   Gtk::Container::on_realize();
-#else
-  if(GTK_WIDGET_CLASS(parent_class)->realize)
-    GTK_WIDGET_CLASS(parent_class)->realize(GTK_WIDGET(gobj()));
-#endif
 
   if(!m_refGdkWindow)
   {
@@ -1031,15 +875,10 @@ void FlowTable::on_unrealize()
 {
   m_refGdkWindow.reset();
 
-#ifdef GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
   Gtk::Container::on_unrealize();
-#else
-  if(GTK_WIDGET_CLASS(parent_class)->unrealize)
-    GTK_WIDGET_CLASS(parent_class)->unrealize(GTK_WIDGET(gobj()));
-#endif
 }
 
-bool FlowTable::on_expose_event(GdkEventExpose* event)
+bool FlowTable::on_draw(const Cairo::RefPtr<Cairo::Context>& cr)
 {
   if(m_design_mode)
   {
@@ -1070,7 +909,7 @@ bool FlowTable::on_expose_event(GdkEventExpose* event)
     }
   }
 
-  return Gtk::Container::on_expose_event(event);
+  return Gtk::Container::on_draw(cr);
 }
 
 bool FlowTable::get_column_for_first_widget(const Gtk::Widget& first, guint& column)
