@@ -153,26 +153,26 @@ bool FlowTableDnd::on_drag_motion(const Glib::RefPtr<Gdk::DragContext>& /* drag_
 void FlowTableDnd::on_dnd_add_layout_item_by_type(int /* item_type */, Gtk::Widget* /* above */)
 {
   //This is not pure virtual, so we can easily use this base class in unit tests.
-  std::cerr << "FlowTableDnd::on_dnd_add_layout_item_by_type(): Not implemented. Derived classes should implement this." << std::endl;
+  std::cerr << G_STRFUNC << ": Not implemented. Derived classes should implement this." << std::endl;
 }
 
 void FlowTableDnd::on_dnd_add_layout_item(LayoutWidgetBase* /* above */, const sharedptr<LayoutItem>& /* item */)
 {
   //This is not pure virtual, so we can easily use this base class in unit tests.
-  std::cerr << "FlowTableDnd::on_dnd_add_layout_item(): Not implemented. Derived classes should implement this." << std::endl;
+  std::cerr << G_STRFUNC << ": Not implemented. Derived classes should implement this." << std::endl;
 
 }
 
 void FlowTableDnd::on_dnd_add_placeholder(Gtk::Widget* /* above */)
 {
   //This is not pure virtual, so we can easily use this base class in unit tests.
-  std::cerr << "FlowTableDnd::on_dnd_add_placeholder(): Not implemented. Derived classes should implement this." << std::endl;
+  std::cerr << G_STRFUNC << ": Not implemented. Derived classes should implement this." << std::endl;
 }
 
 void FlowTableDnd::on_dnd_remove_placeholder()
 {
   //This is not pure virtual, so we can easily use this base class in unit tests.
-  std::cerr << "FlowTableDnd::on_dnd_remove_placeholder(): Not implemented. Derived classes should implement this." << std::endl;
+  std::cerr << G_STRFUNC << ": Not implemented. Derived classes should implement this." << std::endl;
 }
 
 
