@@ -20,13 +20,11 @@
  *   Boston, MA  02110-1301, USA.
  */
 
-#ifndef _GLOM_LAYOUT_WIDGET_UTILS_H_
-#define _GLOM_LAYOUT_WIDGET_UTILS_H_
+#ifndef GLOM_UTILITY_WIDGETS_LAYOUT_WIDGET_UTILS_H
+#define GLOM_UTILITY_WIDGETS_LAYOUT_WIDGET_UTILS_H
 
-#include <gtkmm/widget.h>
-#include <gtkmm/menu.h>
+#include <gtkmm.h>
 #include "layoutwidgetbase.h"
-#include <gtkmm/uimanager.h>
 
 namespace Glom
 {
@@ -56,4 +54,4 @@ protected:
 
 } // namespace Glom
 
-#endif // _GLOM_LAYOUT_WIDGET_UTILS_H_
+#endif // GLOM_UTILITY_WIDGETS_LAYOUT_WIDGET_UTILS_H
