@@ -17,12 +17,8 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
-
-#include <gtkmm/window.h>
-#include <gtkmm/entry.h>
-#include <gtkmm/label.h>
-#include <gtkmm/button.h>
-#include <gtkmm/main.h>
+ 
+#include <gtkmm.h>
 #include "flowtable.h"
 
 
