@@ -1,23 +1,3 @@
-/* Glom
- *
- * Copyright (C) 2010-2011 Murray Cumming
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
- */
- 
 #include <gtkmm.h>
 #include <gtksourceviewmm/init.h>
 #include <glom/glade_utils.h>
@@ -55,7 +35,7 @@
 #include <glom/mode_design/fields/dialog_fielddefinition.h>
 #include <glom/mode_design/dialog_fields.h>
 #include <glom/mode_design/dialog_initial_password.h>
-#include <glom/mode_design/layout/layout_item_dialogs/dialog_groupby_secondaryfields.h>
+#include <glom/mode_design/layout/layout_item_dialogs/dialog_fieldslist.h>
 #include <glom/mode_design/layout/layout_item_dialogs/dialog_groupby_sortfields.h>
 #include <glom/mode_design/layout/layout_item_dialogs/dialog_formatting.h>
 #include <glom/mode_design/script_library/dialog_new_script.h>
@@ -72,7 +52,6 @@
 #include <glom/mode_design/print_layouts/dialog_text_formatting.h>
 #include <glom/dialog_progress_creating.h>
 #include <glom/dialog_invalid_data.h>
-#include <gtksourceviewmm/init.h>
 
 
 template<class T_Widget>
@@ -80,14 +59,14 @@ bool instantiate_widget()
 {
   //Test that the widget can be instantiated with its own glade ID.
   T_Widget* widget = 0;
-  Glom::Utils::get_glade_widget_derived_with_warning(widget);    
+  Glom::Utils::get_glade_widget_derived_with_warning(widget);
   if(!widget)
   {
     std::cerr << "Test: Failed to instantiate widget of type: " << typeid(T_Widget).name() << std::endl;
     exit(EXIT_FAILURE); //Make sure that our test case fails.
     return false;
   }
-    
+
   delete widget;
   return true;
 }
@@ -106,8 +85,8 @@ int main(int argc, char *argv[])
   instantiate_widget<Dialog_Import_CSV>();
   instantiate_widget<Dialog_Import_CSV_Progress>();
   instantiate_widget<DataWidgetChildren::Dialog_ChooseID>();
-  instantiate_widget<DataWidgetChildren::Dialog_ChooseDate>(); 
-  instantiate_widget<Dialog_InvalidData>();   
+  instantiate_widget<DataWidgetChildren::Dialog_ChooseDate>();
+  instantiate_widget<Dialog_InvalidData>();
   instantiate_widget<Dialog_Image_Progress>();
   instantiate_widget<Dialog_ProgressCreating>();
 
@@ -122,13 +101,13 @@ int main(int argc, char *argv[])
   instantiate_widget<Dialog_Layout_Calendar_Related>();
   instantiate_widget<Dialog_Layout_Details>();
   instantiate_widget<Dialog_Layout_List>();
-  //TODO: instantiate_widget<Dialog_Layout_List_Related>();
+  instantiate_widget<Dialog_Layout_List_Related>();
   instantiate_widget<Dialog_ButtonScript>();
   instantiate_widget<Dialog_FlowTable>();
   instantiate_widget<Dialog_ChooseRelationship>();
   instantiate_widget<Dialog_FieldDefinition>();
   instantiate_widget<Box_Formatting>();
-  instantiate_widget<Dialog_GroupBy_SecondaryFields>();
+  instantiate_widget<Dialog_FieldsList>();
   instantiate_widget<Dialog_GroupBy_SortFields>();
   instantiate_widget<Dialog_ImageObject>();
   instantiate_widget<Dialog_Notebook>();
@@ -143,7 +122,7 @@ int main(int argc, char *argv[])
   instantiate_widget<Dialog_NewGroup>();
   instantiate_widget<Dialog_UsersList>();
   instantiate_widget<Dialog_GroupsList>();
-  instantiate_widget<Dialog_ChooseUser>(); 
+  instantiate_widget<Dialog_ChooseUser>();
   instantiate_widget<Dialog_User>();
   instantiate_widget<Dialog_TextFormatting>();
   instantiate_widget<Dialog_Layout_Export>();
@@ -151,6 +130,6 @@ int main(int argc, char *argv[])
   instantiate_widget<Dialog_Database_Preferences>();
   instantiate_widget<Dialog_Fields>();
   instantiate_widget<Dialog_InitialPassword>();
-   
+
   return EXIT_SUCCESS;
 }
